/*
 Licensed Materials - Property of IBM
 5724-T40 IBM License Metric Tool
 5725-C68 IBM Tivoli Asset Discovery for Distributed
 (C) Copyright IBM Corp. 2002, 2011.
 All Rights Reserved. US Government Users Restricted Rights - Use,
 duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 For more detailed help, refer to product manual.
 */
//confidence custom filter
var confMin;
var confMax;
var msgDialogConfidence;
var dropDownButtonWidget;

function closeConfidenceDlg() {
	closeAndDestroyDialog(msgDialogConfidence);
	msgDialogConfidence = null;
	return true;
}

function updateConfidence() {
	var confMinTemp = dijit.byId("confidenceMinSpinner").getValue();
	var confMaxTemp = dijit.byId("confidenceMaxSpinner").getValue();
	if (onChangeConfidence()) {
		setConfidence(confMinTemp, confMaxTemp);
		closeConfidenceDlg();
	}
}

function setConfidence(cmin, cmax) {
	if (cmin != confMin || cmax != confMax) {
		confMin = cmin;
		confMax = cmax;
		hint =  resourceBundle.ConfidenceFilterLabel.replace(/&#39;/g, "'");
		dropDownButtonWidget.set("title", formatLabel(
				hint, [ confMin,
						confMax ]));
		dropDownButtonWidget.set("label", formatLabel(
				resourceBundle.ConfidenceFilterLabel, [ confMin,
						confMax ]));
		lazyTreeModel.query.confMin = confMin;
		lazyTreeModel.query.confMax = confMax;
		refreshAndCollapseTreetable(true);//check modification date and display warning if needed
		buildDownloadCSVLink("DownloadCSV");
		
		saveConfidenceFilterToSession(confMin, confMax);	
	}
}

function onChangeConfidence() {
	dojo.parser.parse();
	var confMinTemp = dijit.byId("confidenceMinSpinner").get('value');
	var confMaxTemp = dijit.byId("confidenceMaxSpinner").get('value');
	var mAreaError = dijit.byId('messageAreaError');
	if (confMinTemp <= confMaxTemp && confMinTemp >= 0 && confMaxTemp <= 100) {
		if(mAreaError){
			mAreaError.hide();
		}
		return true;
	} else {
		if(!mAreaError){
			var div = dojo.create('div',{id : "messageAreaError"},"messageAreaError_placeholder", "after");
			mAreaError = new dojoe.messagearea.MessageArea(null, div);
		}
		mAreaError.setType("critical");
		mAreaError.setMessage(resourceBundle.ConfidenceDialogErrorMinMax);
		mAreaError.setWidth("90%");
		mAreaError.show();
		return false;
	}
}


function saveConfidenceFilterToSession(confMin, confMax) {
	var params = 'target=setConfidenceFilter&confFilterMin=' + confMin + '&confFilterMax=' + confMax + '&sessionId=' + sessionId;
	sendServletRequest('POST', 'ActionServlet', params);
}


function spinnerKeyPress(event){
	if(event.keyCode == 13){ //Enter
		updateConfidence();
	}
}


function createDynamicButton() {
	var filterMenu = new dijit.Menu( {});
	filterMenu.domNode.style.display = "none";
        var hint1 = resourceBundle.ConfidenceFilterChangeFilterSettings.replace(/&#39;/g, "'");
	var filterMenuItem = new dijit.MenuItem( {
		label : resourceBundle.ConfidenceFilterChangeFilterSettings,
		title : hint1,
		iconClass : "filterIcon"
	});
	
	filterMenuItem.onClick = function() {
		msgDialogConfidence = new dijit.Dialog(
				{
					style: "width:420px;height:270px;background-color: white",
					title : resourceBundle.ConfidenceDialogChooseConfidence.replace(/&#39;/,"'"),
					content : "<div style='width:410px;height:190px;overflow:auto'>"
							+ "<table width='400px' height='170px'>"
							+ "<tr><td align='left' colspan='2'>"
							+ "<div id='messageAreaError_placeholder' style='display:none;'></div>"
							+ "</td></tr>"
							+ "<tr ><td align='left' colspan='2' >"
							+ "<div style='width:90%'>"
							+ resourceBundle.ConfidenceFilterInfo
							+ " </div><br/>"
							+ "</td></tr>"
							+ "<tr><td align='left'><label for='confidenceMinSpinner'>"
							+ resourceBundle.ConfidenceDialogMinimalConfidenceLabel
							+ "</label></td>"
							+ "<td align='left'><input dojoType='dijit.form.NumberSpinner' value='"
							+ confMin
							+ "' smallDelta='1'"
							+ "constraints='{min:0,max:100,places:0}' id='confidenceMinSpinner' name='confidenceMin' style='width:60px'"
							+ "largeDelta='10' title='"
							+ resourceBundle.ConfidenceDialogMinimalConfidenceTitle
							+ "' maxLength='3' onChange='onChangeConfidence()' onKeyPress='spinnerKeyPress'/></td></tr>"
							+ "<tr><td align='left'><label for='confidenceMaxSpinner'>"
							+ resourceBundle.ConfidenceDialogMaximalConfidenceLabel
							+ "</label></td>"
							+ "<td align='left'><input dojoType='dijit.form.NumberSpinner' value='"
							+ confMax
							+ "' smallDelta='1'"
							+ "constraints='{min:0,max:100,places:0}' id='confidenceMaxSpinner' name='confidenceMax' style='width:60px'"
							+ "largeDelta='10' title='"
							+ resourceBundle.ConfidenceDialogMaximalConfidenceTitle
							+ "' maxLength='3' onChange='onChangeConfidence()' onKeyPress='spinnerKeyPress'/></td></tr>"
							+ "</table></div><br/>"
							+ "<div align='center'>"
							+ "<table><tr><td>"
							+ "<button dojoType='dijit.form.Button' type='button' title='"
							+ resourceBundle.ConfidenceDialogButtonOK
							+ "' onClick='updateConfidence();'>"
							+ resourceBundle.ConfidenceDialogButtonOK
							+ "</button>"
							+ "<button dojoType='dijit.form.Button' type='button' title='"
							+ resourceBundle.ConfidenceDialogButtonCancel
							+ "'onClick='closeConfidenceDlg();'>"
							+ resourceBundle.ConfidenceDialogButtonCancel
							+ "</button>"
							+ "</td></tr></table>" 
							+ "</div>",

					onHide : closeConfidenceDlg
				});
		dojo.parser.parse();
		msgDialogConfidence.show();
	};
        var hint2 = resourceBundle.ConfidenceFilterClearFilter.replace(/&#39;/g,"'");
	var filterMenuItem2 = new dijit.MenuItem( {
		label : resourceBundle.ConfidenceFilterClearFilter,
		title : hint2,
		iconClass : "clearFilterIcon"
	});
	filterMenuItem2.onClick = function() {
		setConfidence(0, 100);
	};
	filterMenu.addChild(filterMenuItem);
	filterMenu.addChild(filterMenuItem2);
	var paramsForFilter = {
		showLabel : true,
		dropDown : filterMenu,
		dynamic : false,
		iconClass : "filterIcon"
	};
	dropDownButtonWidget = new dijit.form.DropDownButton(paramsForFilter);
	dropDownButtonWidget.set("title", formatLabel(
			resourceBundle.ConfidenceFilterLabel.replace(/&#39;/g,"'"), [ confMin,
					confMax ]));
	dropDownButtonWidget.set("label", formatLabel(
			resourceBundle.ConfidenceFilterLabel, [ confMin,
					confMax ]));

	return dropDownButtonWidget;
}
