/*
 Licensed Materials - Property of IBM
 5724-T40 IBM License Metric Tool
 5725-C68 IBM Tivoli Asset Discovery for Distributed
 (C) Copyright IBM Corp. 2002, 2011.
 All Rights Reserved. US Government Users Restricted Rights - Use,
 duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 For more detailed help, refer to product manual.
 */

var excludeDialog;
var excludeTable;
var excludeStore;
var excludeLayout;
var excludeTableDialog;
var prodInvsToExclude = [];
var textarea = '';
var comboSelected;
var excludeConnectionLinks = [];
var excludeTableFirstFetch;

excludeLayout = [ {
	field : "componentName",
	name : resourceBundle.ExcludeTableDialogComponent,
	width : '40%',
	formatter : displayText
}, {
	field : "hostname",
	name : resourceBundle.TreeTableColumnHostname,
	width : '20%',
	formatter : displayText
}, {
	field : "productName",
	name : resourceBundle.TableColumnProductName,
	width : '40%',
	formatter : displayText
} ];


function showErrorMsg(text){
	var errorArea = dijit.byId('errorArea');
	if (!errorArea){
		var div = dojo.create('div',{id : "errorArea"},"errorArea_placeholder", "after");
		errorArea = new dojoe.messagearea.MessageArea(null, div);
	}
	errorArea.setType("critical");
	errorArea.setMessage(text);
	errorArea.show();	
}

//this function returns length of text encoded in UTF8 in bytes 
function getLengthInBytes(text) {
    var encoded = encodeURI(text);
    if (-1 != encoded.indexOf("%")) { // check if any extended byte is present
        var count = encoded.split("%").length - 1;        
        var charsLeft = encoded.length - (count * 3); // %XX is 3 characters; calculate number of left unencoded ASCII characters 
        count = count + charsLeft;
    } else { // only ascii case
        count = encoded.length;
    }
    return count
 }



function closeExcludeDialogValidate() {
	var textarea = dijit.byId('textarea');
	var combo = document.getElementById('combo');
	var patt = /[#&;<>]/gi;		
	var reasonText = combo.item(combo.selectedIndex).text.replace("\'", "&#39;");
	if (textarea && !(textarea.get('value')) &&  
			(reasonText == resourceBundle.TreeTableHintTextExclusionReasonother)) {
		showErrorMsg(resourceBundle.ProvideExclusionReason);
	} else if (textarea && textarea.get('value') && textarea.get('value').match(patt)) {
		showErrorMsg(resourceBundle.NotAllowedCharacters);
	} else if (textarea && textarea.get('value') && getLengthInBytes(textarea.get('value'))>254 ){
		showErrorMsg(resourceBundle.CommentTooLong);		
	} else {
          if ( releases.length == 0) //instance mode
          {
	    var prodInv = arrayToString(prod_inv_id);
          } else {
            var prodInv = arrayToString(prodInvsToExclude);
          }

		var comment = encodeURIComponent(textarea.get('value'));
		
		var reason = translateExclusionReason(reasonText);

        var query = "target=exclude&productInventoryId=" + prodInv +
        			"&reason=" + reason + "&comment=" + comment + '&sessionId=' + sessionId;
    	var dialog1 = showProgressDlgIndicator('excludeSelected',resourceBundle.ExcludeDialogDialogTitle);

    	var localObjectsToDestroy = {};
    	localObjectsToDestroy["progressDlg"] = dialog1;
    	localObjectsToDestroy["otherObjects"] = [excludeTable, excludeTableDialog];
    	localObjectsToDestroy["connections"] = excludeConnectionLinks;
    	localObjectsToDestroy["store"] = excludeStore;
    	localObjectsToDestroy["mainDialog"] = excludeDialog;
    	
        sendServletRequestAndCleanup('POST', 'ActionServlet', query, localObjectsToDestroy, undefined);
	}
	
};

function translateExclusionReason(comboReason) {
		var reason = "";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasonbackup)
			reason = "backup";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasonbeta)
			reason = "beta";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasoncomponent)
			reason = "component";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasonevaluation)
			reason = "evaluation";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasonno_licensing)
			reason = "no_licensing";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasonnot_compatible)
			reason = "not_compatible";
		if (comboReason === resourceBundle.TreeTableHintTextExclusionReasonother)
			reason = "other";

		return reason;
};

function closeExcludeDialog() {
	closeAndDestroyDialog(excludeDialog);
};

function showExcludedTableDialog(include) {
	textarea = '';
	comboSelected = null;
	loadExcludedTableDialog(include);
};

function closeNoAction() {
	var localObjectsToDestroy = {};
	
	localObjectsToDestroy["progressDlg"] = dialog1;
	localObjectsToDestroy["otherObjects"] = [excludeTable];
	localObjectsToDestroy["connections"] = excludeConnectionLinks;
	localObjectsToDestroy["store"] = excludeStore;
	localObjectsToDestroy["mainDialog"] = null;
	

	
	closeAndDestroyAll(localObjectsToDestroy);
	
	dialog1 = null;
	excludeTableDialog = null;
	excludeTable = null;
	excludeConnectionLinks = [];
	excludeStore = null;

};

function loadExcludedTableDialog(include) {
	excludeTableDialog = new dijit.Dialog({
	    id: 'excludeTableDialog',
	    title: resourceBundle.ExcludeTableDialogTitle.replace(/&#39;/,"'")
	});

	excludeTableDialog.connect(excludeTableDialog, 'onHide', function() {
		setTimeout(function(){ 
			closeNoAction();
			excludeTableDialog.destroyRecursive();
			excludeTableDialog = null;
		}, 0);
	});
	
	

	
	var dialogLabel;
	if (include === 'true')
		dialogLabel = '<label>' + resourceBundle.IncludeTableDialogLabel + '</label>';
	else if (include === 'false')
		dialogLabel = '<label>' + resourceBundle.ExcludeTableDialogLabel + '</label>';
	dialogLabel = '<div width="100%" id="relCountLabel">&nbsp;</div>'+dialogLabel;
		
	// prepare container to dialog content
	var bc = new dijit.layout.BorderContainer({
		style: "height: 400px; width: 700px;",
		gutters: false
	});	
		
	var cp1 = new dijit.layout.ContentPane({
	   region: "top",
	   content: dialogLabel
	});
	bc.addChild(cp1);
	var cp2 = new dijit.layout.ContentPane({
	   region: "center",
	   content: '<div id="excludedTable" style="width: 100%;"></div>'
	});
	bc.addChild(cp2);
	var cp3 = new dijit.layout.ContentPane({
	   region: "bottom",
	   style: "text-align:right",
	   content: '<div id="buttonNext"></div>'	   
	});
	bc.addChild(cp3);
	bc.startup();
	
	excludeTableDialog.attr("content", bc);
	dojo.parser.parse();
	if (0 != releases.length)
	{
	  dojo.html.set(dojo.byId("relCountLabel"),formatLabel(resourceBundle.NumberOfReleases, ""+releases.length));
	}
	showExcludedTable(include);
	showExcludeButton(include);
	excludeTableDialog.show();
};

function showExcludeButton(include) {
	if (include === 'true')
		button  = new dijit.form.Button({
			showLabel: true,						
			label: resourceBundle.IncludeTableButton,
			disabled: true,
			onClick: function() {
				includeSelectedInstances();
			}
		}, 'buttonNext');
	else if (include === 'false')
		button  = new dijit.form.Button({
			showLabel: true,						
			label: resourceBundle.ExcludeTableButton ,
			disabled: true,
			onClick: function() {
				showExcludeConfirmation();
			}
		}, 'buttonNext');
};

function includeSelectedInstances() {
    storeProdInvsToExclude();
    if ( releases.length == 0) //instance mode
    {       
    var prodInv = arrayToString(prod_inv_id);
    } else {
         var prodInv = arrayToString(prodInvsToExclude);
    }

    var query = "target=include&productInventoryId=" + prodInv+'&sessionId='+sessionId;
	var dialog1 = showProgressDlgIndicator('includeSelected',resourceBundle.IncludeDialogDialogTitle);
	
	var localObjectsToDestroy = {};
	localObjectsToDestroy["progressDlg"] = dialog1;
	localObjectsToDestroy["otherObjects"] = [excludeTable, excludeTableDialog];
	localObjectsToDestroy["connections"] = excludeConnectionLinks;
	localObjectsToDestroy["store"] = excludeStore;
	localObjectsToDestroy["mainDialog"] = excludeDialog;
	
    sendServletRequestAndCleanup('POST', 'ActionServlet', query, localObjectsToDestroy, undefined);
    
};

function showExcludedTable() {
	excludeStore = new dojox.data.QueryReadStore({
		url:resourceBundle.contextPath+"/JsonRenderServlet?sessionId=" + sessionId, 
		requestMethod:"post",
		doClientPaging:true,
		doClientSorting:true
	});

	 
        if ( releases.length == 0) //instance mode
        {
	  var query = { target: "exclude", 
                        mode: "instance", 
                        productInventoryId: prod_inv_id.join(",") 
                      };
        }
        else //release mode
        {
        var quickFilter = getQuickFilterTextNotEncoded();
        var query = { 
			target: "exclude", 
			mode: "release", 
			releases: releases.join(","), 
			filterText:quickFilter, 
			startDate:resourceBundle.startDate, 
			endDate:resourceBundle.endDate, 
			confMin:confMin, 
			confMax:confMax,
			viewType:resourceBundle.viewType,
			columnFilterMapping:getColumnFilterMappingAsString() 
        };

        setFilterParamsInQuery(query);
        
       }


		excludeTable = dojoe.table.Table({
		width : '100%',
		height : '100%',
		toolbarVisible: false,
		gridParams : {
			query: query,
			queryOptions: {"deep": true},
			rowsPerPage : 10,
			structure: excludeLayout,
			store: excludeStore,
			plugins: {
				pagination: false,
				indirectSelection: false,
				nestedSorting: false,
				dnd:true
			}
		}
	}, 'excludedTable');
 
	excludeTable.startup();
	
	excludeTableFirstFetch = true;	
	excludeConnectionLinks.push(dojo.connect(excludeTable.grid,"_onFetchComplete", function(items){
		if(excludeTableFirstFetch){
			var buttonNext = dijit.byId('buttonNext');
			if(buttonNext && buttonNext!=null){
				buttonNext.set('disabled', false);
				buttonNext.focus();
			}
			excludeTableFirstFetch = false;
		}
	}));
	
	excludeTable.grid.onFetchError = dojo.hitch(this, onFetchErrorHandler);
};

function closeExcludeTableDialog() {
	var localObjectsToDestroy = {};
	
	localObjectsToDestroy["otherObjects"] = [excludeTable, excludeTableDialog];
	localObjectsToDestroy["connections"] = excludeConnectionLinks;
	localObjectsToDestroy["store"] = excludeStore;
	localObjectsToDestroy["mainDialog"] = excludeDialog;
	
	closeAndDestroyAll(localObjectsToDestroy); 
	
	excludeTable = null;
	excludeTableDialog = null;
	excludeConnectionLinks = [];
	excludeStore = null;
	excludeDialog = null;
};

function storeProdInvsToExclude() {
	prodInvsToExclude = [];
	for (i in excludeTable.grid['store']['_items']) {
			prodInvsToExclude.push(excludeTable.grid['store']['_items'][i]['i']['prodInvId']);
		}
};

function backExcludedTableDialog() {
	textarea = dijit.byId('textarea');
	var combo = document.getElementById('combo');
	
	if (textarea && textarea.get('value')) {
		textarea = textarea.get('value');
	} else {
		textarea = "";
	}
	
	if (combo) {
		comboSelected = combo.selectedIndex;
	}
	
	loadExcludedTableDialog("false");
	closeExcludeDialog();
};

function showExcludeConfirmation() {
		storeProdInvsToExclude();
		excludeTableDialog.hide();
    	excludeDialog = new dijit.Dialog({ 
			title: resourceBundle.ExcludeDialogTitle,
	        onHide: closeExcludeDialog
		});
    	
		
		var bcExcludeDialog = new dijit.layout.BorderContainer({
			style: "height: 400px; width: 700px;",
			gutters: false
		});

		var cpExcludeDialog1  = new dijit.layout.ContentPane({
		   region: "top",
		   style: "height: 15%",
		   content:
				"<div id='errorArea_placeholder' style='display:none;'></div>"+
				"<select id='combo' style='width:70%; display:block;'>"+
				   "<option value='"+resourceBundle.TreeTableHintTextExclusionReasonbackup+"'>"+
				   resourceBundle.TreeTableHintTextExclusionReasonbackup+
				   "</option value='"+resourceBundle.TreeTableHintTextExclusionReasonbeta+"'>"+
				   "<option>"+
				   resourceBundle.TreeTableHintTextExclusionReasonbeta+
				   "</option>"+
				   "<option value='"+resourceBundle.TreeTableHintTextExclusionReasoncomponent+"'>"+
				   resourceBundle.TreeTableHintTextExclusionReasoncomponent+
				   "</option>"+
				   "<option value='"+resourceBundle.TreeTableHintTextExclusionReasonevaluation+"'>"+
				   resourceBundle.TreeTableHintTextExclusionReasonevaluation+
				   "</option>"+
				   "<option value='"+resourceBundle.TreeTableHintTextExclusionReasonno_licensing+"'>"+
				   resourceBundle.TreeTableHintTextExclusionReasonno_licensing+
				   "</option>"+
				   "<option value='"+resourceBundle.TreeTableHintTextExclusionReasonnot_compatible+"'>"+
				   resourceBundle.TreeTableHintTextExclusionReasonnot_compatible+
				   "</option>"+
				   "<option value='"+resourceBundle.TreeTableHintTextExclusionReasonothe+"'>"+
				   resourceBundle.TreeTableHintTextExclusionReasonother+
				   "</option>"+
				"</select>"
		});
		bcExcludeDialog.addChild(cpExcludeDialog1);
		var cpExcludeDialog2 = new dijit.layout.ContentPane({
		   region: "center",
		   content:
				resourceBundle.ProvideExclusionReason +
				"<div id='textarea' dojoType='dijit.form.SimpleTextarea' maxLength=254 style='width: 80%; height: 80%;'></div>"
		});
		bcExcludeDialog.addChild(cpExcludeDialog2);
		var cpExcludeDialog3 = new dijit.layout.ContentPane({
		   region: "bottom",
		   style: "text-align:right",
		   content: 
				"<div id='buttonBack' dojoType='dijit.form.Button' onClick='backExcludedTableDialog();' style='align: right'>"+resourceBundle.ExcludeTableButtonLabelBack+"</div>"+
				"<div id='buttonExclude' dojoType='dijit.form.Button' onClick='closeExcludeDialogValidate();' style='align: right'>"+resourceBundle.ExcludeTableButtonLabelExclude+"</div>"
		});
		bcExcludeDialog.addChild(cpExcludeDialog3);
		bcExcludeDialog.startup();
		excludeDialog.attr("content", bcExcludeDialog);		
		document.getElementById('combo').selectedIndex = comboSelected;
		dijit.byId('textarea').setValue(textarea);
    	excludeDialog.show();
    };
