/*
 Licensed Materials - Property of IBM
 5724-T40 IBM License Metric Tool
 5725-C68 IBM Tivoli Asset Discovery for Distributed
 (C) Copyright IBM Corp. 2002, 2011.
 All Rights Reserved. US Government Users Restricted Rights - Use,
 duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 For more detailed help, refer to product manual.
 */

var tableShareInstances;
var buttonShareInstances;
var shareInstancesLayout;
var shareInstanceDialog;
var jsonStoreShareTable;
var firstFetchCompleted;
var lastSelection;
var shareConnectionLinks= [];

shareInstancesLayout = [ {
	field : "productName",
	name : resourceBundle.TableColumnProductName,
	width : '50%',
	formatter : displayText
}, {
	field : "confidenceLevel",
	name : resourceBundle.TableColumnConfidenceLevel,
	width : '20%',
	formatter : displayPercentage,
	datatype: "number"
}, {
	field : "appliedRules",
	name : resourceBundle.TableColumnApplicableRules,
	width : '30%',
	formatter : displayText
} ];


function showSharedLabel(numberOfReleases){
	dojo.html.set(dojo.byId("shareLabel"),formatLabel(resourceBundle.NumberOfReleases, ""+numberOfReleases));
};


function showShareDialog() {
	// set the content of the dialog:
	shareInstanceDialog = new dijit.Dialog(
			{
				id : 'shareDialog',
				title : resourceBundle.SharedDialogTitle.replace(/&#39;/g,"'"),
				onHide : closeNoAction,
			});

	var bc = new dijit.layout.BorderContainer({
		style: "height: 400px; width: 700px;",
		gutters: false
	});	

	var html ='<table border="0" width="100%"><tr><td><div width="100%" id="shareLabel"></div></td>';
	html +='<td align="right" ><div align="right" id="shareButtonClose"></div></td></tr></table>';
	
	var cp1 = new dijit.layout.ContentPane({
	   region: "center",
	   content: '<div id="tableShareInstances" style="width: 100%;"></div>'
	});
	bc.addChild(cp1);

	var cp2 = new dijit.layout.ContentPane({
	   region: "bottom",
	   content: html	   
	});
	bc.addChild(cp2);
	bc.startup();
	
	shareInstanceDialog.attr("content", bc);	

	dojo.parser.parse();
	setTimeout(dojo.hitch(this, function(){  //this prevents error occurrence while table data loading
		showSharedTable();
		showSharedButton();
		shareInstanceDialog.show();
		var count = 0 ; 
		firstFetchCompleted = false;
		shareConnectionLinks.push(dojo.connect(tableShareInstances.grid, "_onFetchComplete", function(items, req){
			if(!firstFetchCompleted){
				//initialize selection only once
				var items2=jsonStoreShareTable._items;
				lastSelection = {};		
				for(i=0; i<items2.length; i++) {
					if (items2[i]['i']['isSelected'] === 'true'){
						tableShareInstances.grid.selection.addToSelection(i);
						lastSelection[items2[i]['i']['id']] = true;
						count++;
					}
				}
				//First time 
				showSharedLabel(count);
				shareConnectionLinks.push(dojo.connect(tableShareInstances.grid, "onSelectionChanged", function(item) {
					var deferred = tableShareInstances.grid.selection.getSelectedItems();
					deferred.then(function(selected){
				       	//Do something on success.
						lastSelection={};
						for(var i=0;i<selected.length;i++){ //store current selections
							lastSelection[selected[i]['i']['id']] = true;
						}
						buttonShareInstances.set('disabled', (selected.length < 1));
						buttonShareInstances.focus();
						//Update View
						showSharedLabel(selected.length);
					},
				    function(error){
				      //Do something on failure.
						console.log(error);
					});	
	
				}));
				firstFetchCompleted = true;
			}
		}));
	}), 200);
};

function closeShareDialog() {
	var deferred = tableShareInstances.grid.selection.getSelectedItems();
	deferred.then(function(selected){
		//Do something on success.
		var productIds = jsonStoreShareTable.getValue(selected[0],'productId');
		for (i=1; i < selected.length; i++) {
			productIds += "," +  jsonStoreShareTable.getValue(selected[i],'productId');
		}
		var prodInvId = prod_inv_id[0];
		var updateTimes = updateTime[0];
		
		var formData = "target=share&productInventoryId="
					+ prodInvId
					+ "&productIds="
					+ productIds
					+ "&updateTime=" + updateTimes
					+ "&sessionId=" + sessionId;
		var dialog1 = showProgressDlgIndicator('shareSelected',resourceBundle.SharedDialogDialogTitle);
		
		var localObjectsToDestroy = {};
		localObjectsToDestroy["progressDlg"] = dialog1;
		localObjectsToDestroy["otherObjects"] = [tableShareInstances];
		localObjectsToDestroy["connections"] = shareConnectionLinks;
		localObjectsToDestroy["store"] = jsonStoreShareTable;
		localObjectsToDestroy["mainDialog"] = shareInstanceDialog;

		sendServletRequestAndCleanup('POST', 'ActionServlet', formData, localObjectsToDestroy, undefined);
		
    },
    function(error){
      //Do something on failure.
		console.log(error);
  });
};

function showSharedButton() {
	buttonShareInstances = new dijit.form.Button( {
		showLabel : true,
		label : resourceBundle.SharedButtonText,
		disabled : false,
		onClick : closeShareDialog
	}, 'shareButtonClose');
};


function closeNoAction() {
	var localObjectsToDestroy = {};
	
	localObjectsToDestroy["otherObjects"] = [tableShareInstances];
	localObjectsToDestroy["connections"] = shareConnectionLinks;
	localObjectsToDestroy["store"] = jsonStoreShareTable;
	localObjectsToDestroy["mainDialog"] = shareInstanceDialog;
	
	closeAndDestroyAll(localObjectsToDestroy);
	
	tableShareInstances = null;
	shareConnectionLinks = [];
	jsonStoreShareTable = null;
	shareInstanceDialog = null;
};

function showSharedTable() {
	jsonStoreShareTable = new dojox.data.QueryReadStore( {
		url : resourceBundle.contextPath +"/JsonRenderServlet?sessionId="+sessionId,
		requestMethod : "post",
		doClientPaging:true,
		doClientSorting:true
	});

	createShareTableWidgets();

//	changeGetSelectedFunction(tableShareInstances);

	tableShareInstances.grid.onFetchError = dojo.hitch(this, onFetchErrorHandler);	
	
	tableShareInstances.grid.selection.clear = function(){//do nothing to avoid clearing selection when filtering
	};

	tableShareInstances.grid.pluginMgr.getPlugin("Filter").grid.layer('filter')._applyFilter =  function(datarow,rowIndex){
		// summary:
		// Apply the filter to a row of data
		// tags:
		// private
		// returns:
		// whether this row survived the filter.
		//this is a modified version of the original Dojo function to change filter logic for Share table 
		var g = this._getter, s = this._store;
		try{			
			return lastSelection[datarow['i']['id']] //is currently selected 
				|| !!( this._filter.applyRow(datarow, function(item, arg){//matches filter criteria
						return g(item, arg, rowIndex, s);
						}).getValue());
		}catch(e){
			console.warn("FilterLayer._applyFilter() error: ", e);
			return false;
		}
	};
	
};


function createShareTableWidgets() {

	tableShareInstances = new dojoe.table.Table( {
		width : '100%',
		height : '100%',
		gridParams : {
			query : {
				target : "share",
				productInventoryId : prod_inv_id.join(",")
			},
			queryOptions : {
				"deep" : true
			},
			structure : shareInstancesLayout,
			store : jsonStoreShareTable,
			selectionMode : 'multiple',
			plugins : {
				selector: {noClear: true, cell: false},
				indirectSelection: {"headerSelector" : false},
				nestedSorting : true,
				dnd : true,
				filter : {
					advancedFilter : true,
					quickFilter : true,
					ruleCount : 0,
					showQuickFilterButton : true
				},
				pagination : false
			}
		},
		toolbarOptions : {
			refreshIcon:false,
			actionMenu:false,
			configTableIcon:false, configTableMenu: false,
			exporterIcon: false, exporterMenu: false,
			printerIcon:false, printerMenu: false											
		}
	}, 'tableShareInstances');
	
	tableShareInstances.startup();
}
