/*
 Licensed Materials - Property of IBM
 5724-T40 IBM License Metric Tool
 5725-C68 IBM Tivoli Asset Discovery for Distributed
 (C) Copyright IBM Corp. 2002, 2011.
 All Rights Reserved. US Government Users Restricted Rights - Use,
 duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 For more detailed help, refer to product manual.
 */

var layout;
var layoutList;
var filterColumnList;
var hideEmptyColumns = true;

displayProgress = function(item){
	var confidence = jsonStore.getValue(item, "confidence");	
	
	if(confidence && confidence !== '') {
		if(parseInt(confidence) === -1){
			return  "<div align='center'><img src='resources/images/aggregationPendingLoading.gif' alt='"+resourceBundle.TreeTableHintTextConfidencePending+"' title='"+resourceBundle.TreeTableHintTextConfidencePending+"' /> </div>";
		}else{
			var props = { maximum: 100, progress: confidence, showTitle: true, style: "height:100%" };
			var progressBar = new dijit.ProgressBar(props);
			progressBar._destroyOnRemove = true;
			
			if(parseInt(confidence) === 100){
				dojo.query(".dijitProgressBarTile", progressBar.domNode).addClass("progressGreen");
			}else if(parseInt(confidence) >= 50){
				dojo.query(".dijitProgressBarTile", progressBar.domNode).addClass("progressOrange");
			}else{
				dojo.query(".dijitProgressBarTile", progressBar.domNode).addClass("progressRed");
			}			
	
			if (jsonStore.getValue(item, "level") !== "instance") {
				progressBar.set("title", resourceBundle.TreeTableHintTextConfidenceExplanation.replace(/&#39;/g,"'"));
			} else {
				var title;
				if (jsonStore.getValue(item, "isSimple") === "true") {
					title = resourceBundle.RuleDescriptionSimple;
				} else {
					if (jsonStore.getValue(item, "isUnconfirmed") == "true") {
						title = resourceBundle.RuleDescriptionUnconfirmed;	
					} else {						
						var rules = jsonStore.getValue(item, "bundleRules");
						if(rules && rules !== ""){
							title = resourceBundle.RuleDescriptionConfirmed;
						} else {
							title = resourceBundle.RuleDescriptionRebundled;
						}
					}
				} 
				progressBar.set("title", title.replace(/&#39;/g,"'"));
			}				
	
			return  progressBar;
		}
	}else{
		return confidence;
	}		
};		

displayRules = function(item){
	var text;
	if (jsonStore.getValue(item, "level") !== "instance") {
		text = "";
	} else {
		if (jsonStore.getValue(item, "isSimple") === "true") {
			text = resourceBundle.ConfidenceExplanationSimple;
		} else {
			var rules = jsonStore.getValue(item, "bundleRules");
			if (jsonStore.getValue(item, "isUnconfirmed") === "true") {
				text = formatLabel(resourceBundle.ConfidenceExplanationUnconfirmed,rules);	
			} else {						
				if(rules && rules !== ""){
					text = formatLabel(resourceBundle.ConfidenceExplanationConfirmed,rules);
				} else {
					text = resourceBundle.ConfidenceExplanationRebundled;
				}
			}
		} 			
	}		
	return text;
};		

displayProductReleaseComponent = function(item){
	var result = '<div style="margin-left: 20px;">';
	if (jsonStore.getValue(item, "level") == "release") {
		result += formatLabel( resourceBundle.Release, 
				[ jsonStore.getValue(item, "productReleaseComponent"), jsonStore.getValue(item, "numberOfAllInstances") ]);
	}
	else {
		result += jsonStore.getValue(item, "productReleaseComponent");		
	}
	
	result += "&nbsp;";
	

	if((jsonStore.getValue(item, "isSubCap") == "false") &&
			((jsonStore.getValue(item, "level") == "product") || 
					((jsonStore.getValue(item, "level") == "release") && (resourceBundle.viewType == "STG_PRODUCTS")))) {
		result += "<img src='resources/images/fullCapacityProduct_obj.gif' alt='"+resourceBundle.TreeTableHintTextFullCapacityProduct+"' title='"+resourceBundle.TreeTableHintTextFullCapacityProduct+"' /> ";
	}
	
	var exclusionReason = jsonStore.getValue(item, "exclusionReason");
	if(exclusionReason) {
		var reasons = []; 
		reasons["backup"] = 		resourceBundle.TreeTableHintTextExclusionReasonbackup;
		reasons["beta"] = 			resourceBundle.TreeTableHintTextExclusionReasonbeta;
		reasons["component"] = 		resourceBundle.TreeTableHintTextExclusionReasoncomponent;
		reasons["evaluation"] = 	resourceBundle.TreeTableHintTextExclusionReasonevaluation;
		reasons["incomplete_wca"] =	resourceBundle.TreeTableHintTextExclusionReasonincomplete_wca;
		reasons["maintenance"] = 	resourceBundle.TreeTableHintTextExclusionReasonmaintenance;
		reasons["no_licensing"] = 	resourceBundle.TreeTableHintTextExclusionReasonno_licensing;
		reasons["not_compatible"] =	resourceBundle.TreeTableHintTextExclusionReasonnot_compatible;
		reasons["other"] = 			resourceBundle.TreeTableHintTextExclusionReasonother;
		
		var title = resourceBundle.TreeTableHintTextExcluded+"&nbsp;";
		title += reasons[exclusionReason];
		
		if(exclusionReason === "other") title += ("&nbsp;" + dojox.html.entities.encode(jsonStore.getValue(item, "exclusionComment")));
		
		result += "<img src='resources/images/excludedInstance.gif' alt='" + title + "' title='" + title + "' /> ";
	}
	
	if(jsonStore.getValue(item, "isCharged") == "false") {
		result += "<img src='resources/images/freeInstance.png' alt='"+resourceBundle.TreeTableHintTextFreeInstance+"' title='"+resourceBundle.TreeTableHintTextFreeInstance+"' /> ";
	}
	
	if(jsonStore.getValue(item, "isOnSharedDisk") == "true") {
		result += "<img src='resources/images/instanceOnSharedDisk.gif' alt='"+resourceBundle.TreeTableHintTextInstanceOnSharedDisk+"' title='"+resourceBundle.TreeTableHintTextInstanceOnSharedDisk+"' /> ";
	}
	result += '</div>';
	
	return result;
};

displayExclusionStatus = function(item){
	var level = jsonStore.getValue(item, "level");
	if (jsonStore.getValue(item, "level") !== "instance") {
		return "";
	}
	var exclusionReason = jsonStore.getValue(item, "exclusionReason");
	var reasons = []; 
	reasons["backup"] = 		resourceBundle.TreeTableHintTextExclusionReasonbackup;
	reasons["beta"] = 			resourceBundle.TreeTableHintTextExclusionReasonbeta;
	reasons["component"] = 		resourceBundle.TreeTableHintTextExclusionReasoncomponent;
	reasons["evaluation"] = 	resourceBundle.TreeTableHintTextExclusionReasonevaluation;
	reasons["incomplete_wca"] =	resourceBundle.TreeTableHintTextExclusionReasonincomplete_wca;
	reasons["maintenance"] = 	resourceBundle.TreeTableHintTextExclusionReasonmaintenance;
	reasons["no_licensing"] = 	resourceBundle.TreeTableHintTextExclusionReasonno_licensing;
	reasons["not_compatible"] =	resourceBundle.TreeTableHintTextExclusionReasonnot_compatible;
	reasons["other"] = 			resourceBundle.TreeTableHintTextExclusionReasonother;
	
	var includedText =       	resourceBundle.TreeTableTextIncluded;
	var excludedText = 			resourceBundle.TreeTableHintTextExcluded;
	var result;
	
	/*Check if the user has click to expand the exclusion reason and keep the text expanded when refreshing the table also, call ther formatter code*/
	/*Check if the user has click to expand the exclusion reason and keep the text expanded when refreshing the table also, call ther formatter code*/
		if (listOfDivs != undefined){	  
	  if (listOfDivs[jsonStore.getValue(item, "productInventoryId")] != undefined) {
	      result = setExclusionReson(jsonStore, includedText, excludedText, item, reasons, exclusionReason, 'inline', '',"back"); //Collapse the exclusion reason		  
	  }else{
	      result = setExclusionReson(jsonStore, includedText, excludedText, item, reasons, exclusionReason, 'none', '...', "forward"); //Expand Exclusion reason	      
	  }
	}else {
	  result = setExclusionReson(jsonStore, includedText, excludedText, item, reasons, exclusionReason, 'none', '...', "forward"); //Collapse the exclusion reason		   
	}
	
	return result;	
};

getColumnAligment = function(columnName, value){
	if(columnName =="pvuSub"
		|| columnName =="pvuFull"
		|| columnName =="serverCoresLimit"
		|| columnName =="serverCoresSub"
		|| columnName =="serverPvuLimit"
		|| columnName =="serverPvuSub"
		|| columnName =="cpuCoreFull"
		|| columnName =="cpuCoreSub"
		|| columnName =="partitionCores"
		|| columnName =="partitionId"
		|| columnName =="maxPartitionCores" 
		|| columnName =="cpuCores")
	{
		return displayNumber(value);
	}else{
		return value;
	}
};
displayAggregationOutputColumn = function(item, columnName, level) {
	if(jsonStore.getValue(item, "level") !== level) return "";

	result = "";

	if(jsonStore.getValue(item, "isAggrPending") == "true") {
		//Column name and value.
		result += getColumnAligment(columnName,"<img src='resources/images/aggregationPendingLoading.gif' alt='"+resourceBundle.TreeTableHintTextAggregationPending+"' title='"+resourceBundle.TreeTableHintTextAggregationPending+"' />&nbsp;");
	} else if(jsonStore.getValue(item, columnName) == null || jsonStore.getValue(item, columnName) == "") {
		title = resourceBundle.TreeTableHintTextAggregationOutputUnavailable+"&nbsp;";
	
		if(columnName.indexOf("Sub") != -1 && jsonStore.getValue(item, "isSubCap") == "false") {
			title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonFullCapacityProduct+"&nbsp;";
		} else if(jsonStore.getValue(item, "isCharged") == "false" && jsonStore.getValue(item, "level") == "instance") {
				title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonFreeInstance+"&nbsp;";
		} else if(resourceBundle.viewType == 'STG_PRODUCTS' && jsonStore.getValue(item), "isCharged" == "false" && jsonStore.getValue(item, "level") !== "instance") {
			title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonOnlyFreeInstances+"&nbsp;";		
		} else if (jsonStore.getValue(item, "partNumbers") != "" && jsonStore.getValue(item, "children") == "false") {			
			title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonNoInstancesForPartNumber+"&nbsp;";
		} else if(resourceBundle.viewType == 'STG_PRODUCTS' && jsonStore.getValue(item, "isRemote") == "true") {
			if(jsonStore.getValue(item, "level") !== "instance"){
				title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonOnlyInstancesOnSharedDisks+"&nbsp;";
			}
			else{
				title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonInstanceOnSharedDisks+"&nbsp;";
			}
		} else if(resourceBundle.viewType == 'PVU_PRODUCTS' && jsonStore.getValue(item, "isOnSharedDisk") == "true" && jsonStore.getValue(item, "level") == "instance"){
			title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonInstanceOnSharedDisks+"&nbsp;";
		} else if(columnName == "partitionCores" && jsonStore.getValue(item, "maxPartitionCores")) {
			title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonInstanceNotInPeak+"&nbsp;";
		} else if (columnName.indexOf("server") != -1) {
			if (jsonStore.getValue(item, "isSubCap") == "false") {
				title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonFullCapacityProduct+"&nbsp;";
			} else {
				title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonInstanceNotInPeak+"&nbsp;"; 
			}
		}
		//is free or remote and is product level on PVU_PRODUCTS
		else if(jsonStore.getValue(item, "level") !== "instance" && resourceBundle.viewType == 'PVU_PRODUCTS')
			title += resourceBundle.TreeTableHintTextAggregationOutputUnavailableReasonInstancesOnSharedDisksOrFreeInstances+"&nbsp;";
		
		result += getColumnAligment(columnName,"<img src='resources/images/aggregationOutputUnavailable.gif' alt='" + title + "' title='" + title + "' />&nbsp;");
	} else {
		var value = jsonStore.getValue(item, columnName);
		//Align the numbers to the right into the cell if the column represents numbers.
		result += getColumnAligment(columnName,value);
	}
	
	
	return result;
};

displayServerId = function(item) {
	var processor = "";
	if(item.indexOf("TLM_VM") === 0) {
		processor += "<img src='resources/images/agentstatusIncomplete_obj.gif' alt='"+resourceBundle.VmManagerMissing+"' title='"+resourceBundle.VmManagerMissing+"' />&nbsp;";
	}
	processor += item;
	return processor;
};

displayCpuCoreFull = function (item) { return displayAggregationOutputColumn(item, "cpuCoreFull", "product"); };
displayCpuCoreSub = function (item) { return displayAggregationOutputColumn(item, "cpuCoreSub", "product"); };
displayPvuFull = function (item) { return displayAggregationOutputColumn(item, "pvuFull", "product"); };
displayPvuSub = function (item) { return displayAggregationOutputColumn(item, "pvuSub", "product"); };
displayPartitionCores = function (item) { return displayAggregationOutputColumn(item, "partitionCores", "instance"); };
displayServerCpuCoresLimit = function (item) { return displayAggregationOutputColumn(item, "serverCoresLimit", "instance"); };
displayServerCpuCoresSub = function (item) { return displayAggregationOutputColumn(item, "serverCoresSub", "instance"); };
displayServerPvuLimit = function (item) { return displayAggregationOutputColumn(item, "serverPvuLimit", "instance"); };
displayServerPvuSub = function (item) { return displayAggregationOutputColumn(item, "serverPvuSub", "instance"); };
displayServerIdForPeak = function (item) { return displayAggregationOutputColumn(item, "serverNameForPeak", "instance"); };
displayServerSystemModel = function (item) { return displayAggregationOutputColumn(item, "serverSystemModel", "instance"); };
displayServerTier = function (item) { return displayAggregationOutputColumn(item, "serverTier", "instance"); };
displayServerCpuCores = function (item) { return displayAggregationOutputColumn(item, "serverCores", "instance"); };
displayPartitionId = function (item) { return displayAggregationOutputColumn(item, "partitionId", "instance"); };
displayMaxPartitionCores = function (item) { return displayAggregationOutputColumn(item, "maxPartitionCores", "instance"); };
displayCpuCores = function (item) { return displayAggregationOutputColumn(item, "cpuCores", "release"); };

displayHostname = function (item) {
	var result = "";
	
	var hostname = jsonStore.getValue(item, "hostname");
	if(hostname) result += hostname; 
	if(jsonStore.getValue(item, "isAgentDeleted") == "true") {
		result += "&nbsp;<img src='resources/images/agentDeleted_obj.gif' alt='"+resourceBundle.TreeTableHintTextAgentDeleted+"' title='"+resourceBundle.TreeTableHintTextAgentDeleted+"' />";
	}
	
	return result;
};

displayInstallationPaths = function (item) {
	var result = "";
	
	var installationPaths = jsonStore.getValue(item, "installationPaths");
	if(installationPaths) { 
		result += installationPaths; 
	} else {
		// to see if we are on instance level
		if (jsonStore.getValue(item, "level") === "instance") {			
			result = "<div title='" + resourceBundle.TreeTableHintTextPathNotExists +"'>";
			result += resourceBundle.TreeTablePathNotExists;
			result += "</div>";
		}
	}

	return result;		
};

function initTreeTableLayout(){
	//columns identical for all 3 types of views
	if(layoutList == undefined || layoutList == null){
		layoutList = {};
		layoutList.ALL_PRODUCTS = [
		    //width of first column is also adjusted in TreeTableMain.js in function that connects to "toggleLoadingClass"
			{field: "_item", name: resourceBundle.TreeTableColumnProductReleaseComponent, width: '100%', formatter: displayProductReleaseComponent, hiddenDefault: false},
			{field: "_item", name: resourceBundle.TreeTableColumnHostname, width: 10, formatter: displayHostname, hiddenDefault: false, filter: "name_host_filter", instanceLevelOnly: true, hidden: true},
			{field: "_item", name: resourceBundle.TreeTableColumnConfidence, width: 8, formatter: displayProgress, hiddenDefault: false, instanceLevelOnly: false},
			{field: "_item", name: resourceBundle.TreeTableColumnBundleRules, width: 13, formatter: displayRules, hiddenDefault: false, instanceLevelOnly: true, hidden: true},
			{field: "currentServerId", name: resourceBundle.TreeTableColumnCurrentServerId, width: 9, formatter: displayServerId, hiddenDefault: false, filter: "name_server_filter", instanceLevelOnly: true, hidden: true},
			{field: "_item", name: resourceBundle.TreeTableColumnExclusionStatus, width: 13, formatter: displayExclusionStatus, hiddenDefault: true, filter: "exclusion_status_filter", instanceLevelOnly: true, hidden: true}
		];
		if(isTAD4D) {
			layoutList.ALL_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnInstallationPaths, width: 9, formatter: displayInstallationPaths, hiddenDefault: false, filter: "path_filter", instanceLevelOnly: true, hidden: true});
		}
	
		layoutList.PVU_PRODUCTS = layoutList.ALL_PRODUCTS.slice(0);//copy
		layoutList.STG_PRODUCTS = layoutList.ALL_PRODUCTS.slice(0);//copy
		layoutList.STG_PRODUCTS[0] = {field: "_item", name: resourceBundle.TreeTableColumnReleaseComponent, width: 30, formatter: displayProductReleaseComponent, hiddenDefault: false};
			
		///////////////////// ALL Products View /////////////////////
		layoutList.ALL_PRODUCTS.push({field: "operatingSystem", name: resourceBundle.TreeTableColumnOperatingSystem, width: 7, formatter: displayText, hiddenDefault: false, filter: "operating_system_filter", instanceLevelOnly: true, hidden: true });
		layoutList.ALL_PRODUCTS.push({field: "scanGroup", name: resourceBundle.TreeTableColumnScanGroup, width: 7, formatter: displayText, hiddenDefault: false, filter: "scan_group_filter", instanceLevelOnly: true, hidden: true });
		layoutList.ALL_PRODUCTS.push({field: "partNumbers", name: resourceBundle.TreeTableColumnPartNumbers, width: 9, formatter: displayText, hiddenDefault: false, filter: "part_number_filter", instanceLevelOnly: false});
		
		if(isTAD4D) {
			layoutList['ALL_PRODUCTS'].push({field: "manufacturer", name: resourceBundle.TreeTableColumnManufacturer, width: 8, formatter: displayText, hiddenDefault: false, filter: "vendor_filter", instanceLevelOnly: false });
		}
	
		///////////////////// PVU Products View /////////////////////	
		layoutList.PVU_PRODUCTS.push({field: "operatingSystem", name: resourceBundle.TreeTableColumnOperatingSystem, width: 7, formatter: displayText, hiddenDefault: true, filter: "operating_system_filter", instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "scanGroup", name: resourceBundle.TreeTableColumnScanGroup, width: 7, formatter: displayText, hiddenDefault: true, filter: "scan_group_filter", instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "processorType", name: resourceBundle.TreeTableColumnProcessorType, width: 8, formatter: displayText, hiddenDefault: false, filter: "processor_filter", instanceLevelOnly: true, hidden: true});
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerIdForPeak, width: 9, formatter: displayServerIdForPeak, hiddenDefault: true, filter: "server_name_for_peak_filter", instanceLevelOnly: true, hidden: true});
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerCpuCoresLimit, width: 7, formatter: displayServerCpuCoresLimit, hiddenDefault: true, instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerCpuCoresSub, width: 7, formatter: displayServerCpuCoresSub, hiddenDefault: true, instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerPvuLimit, width: 7, formatter: displayServerPvuLimit, hiddenDefault: true, instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerPvuSub, width: 7, formatter: displayServerPvuSub, hiddenDefault: false, instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "pvuPerCore", name: resourceBundle.TreeTableColumnPvuPerCore, width: 7, formatter: displayNumber, hiddenDefault: false, instanceLevelOnly: true, hidden: true });
		layoutList.PVU_PRODUCTS.push({field: "partNumbers", name: resourceBundle.TreeTableColumnPartNumbers, width: 9, formatter: displayText, hiddenDefault: false, filter: "part_number_filter", instanceLevelOnly: false});
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnPvuFull, width: 11, formatter: displayPvuFull, hiddenDefault: false, instanceLevelOnly: false });
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnPvuSub, width: 11, formatter: displayPvuSub, hiddenDefault: false, instanceLevelOnly: false });
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnCpuCoreFull, width: 7, formatter: displayCpuCoreFull, hiddenDefault: true, instanceLevelOnly: false });
		layoutList.PVU_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnCpuCoreSub, width: 7, formatter: displayCpuCoreSub, hiddenDefault: true, instanceLevelOnly: false });
	
		///////////////////// STG Products View ///////////////////// 
		layoutList.STG_PRODUCTS.push({field: "operatingSystem", name: resourceBundle.TreeTableColumnOperatingSystem, width: 7, formatter: displayText, hiddenDefault: true, filter: "operating_system_filter", instanceLevelOnly: true, hidden: true});
		layoutList.STG_PRODUCTS.push({field: "scanGroup", name: resourceBundle.TreeTableColumnScanGroup, width: 7, formatter: displayText, hiddenDefault: true, filter: "scan_group_filter", instanceLevelOnly: true, hidden: true});
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerIdForPeak, width: 9, formatter: displayServerIdForPeak, hiddenDefault: false, filter: "server_name_for_peak_filter", instanceLevelOnly: true, hidden: true});
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerSystemModel, width: 7, formatter: displayServerSystemModel, hiddenDefault: false, filter: "server_system_model_filter", instanceLevelOnly: true, hidden: true});
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerTier, width: 5, formatter: displayServerTier, hiddenDefault: false, filter: "server_tier_filter", instanceLevelOnly: true, hidden: true});
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnServerCpuCores, width: 5, formatter: displayServerCpuCores, hiddenDefault: true, instanceLevelOnly: true, hidden: true });
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnPartitionId, width: 6, formatter: displayPartitionId, hiddenDefault: false, filter: "partition_id_filter", instanceLevelOnly: true, hidden: true});
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnPartitionCores, width: 7, formatter: displayPartitionCores, hiddenDefault: false, instanceLevelOnly: true, hidden: true });
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnMaxPartitionCores, width: 8, formatter: displayMaxPartitionCores, hiddenDefault: false, instanceLevelOnly: true, hidden: true });
		layoutList.STG_PRODUCTS.push({field: "_item", name: resourceBundle.TreeTableColumnCpuCores, width: 6, formatter: displayCpuCores, hiddenDefault: false, instanceLevelOnly: false });
	}
	layout = layoutList[resourceBundle.viewType];

	//loadColumnVisibility() will pick the columns that should be displayed depending on session settings
	
	//prepare list for filter column combobox
	filterColumnList = [
			{name: resourceBundle.TreeTableColumnProductReleaseComponent, columnName: "product_release_component_filter"},
			{name: resourceBundle.TreeTableColumnHostname, columnName: "name_host_filter"},
			{name: resourceBundle.TreeTableColumnCurrentServerId, columnName: "name_server_filter"},
			{name: resourceBundle.TreeTableColumnOperatingSystem, columnName: "operating_system_filter"},
			{name: resourceBundle.TreeTableColumnScanGroup, columnName: "scan_group_filter"}
		];
		
	if(resourceBundle.viewType == "ALL_PRODUCTS"){
		filterColumnList.push({name: resourceBundle.TreeTableColumnPartNumbers, columnName: "part_number_filter"});
			
		if(isTAD4D) {
			filterColumnList.push({name: resourceBundle.TreeTableColumnManufacturer, columnName: "vendor_filter"});
		}
	}
	else if(resourceBundle.viewType == "PVU_PRODUCTS"){
		filterColumnList.push({field: "processorType", name: resourceBundle.TreeTableColumnProcessorType, columnName: "processor_filter"});
		filterColumnList.push({name: resourceBundle.TreeTableColumnPartNumbers, columnName: "part_number_filter"});		
	}
	else if(resourceBundle.viewType == "STG_PRODUCTS"){
		filterColumnList[0] = {name: resourceBundle.TreeTableColumnReleaseComponent, columnName: "product_release_component_filter"};
	}
}

imgout=new Image(16,16);
imgin=new Image(16,16);


imgout.src="resources/images/arrow_forward.png";
imgin.src="resources/images/arrow_back.png";


//this switches expand collapse icons
function filter(imagename,objectsrc){
	if (document.images){
		document.images[imagename].src=eval(objectsrc+".src");
	}
}

var listOfDivs = [];
//show OR hide funtion depends on if element is shown or hidden
function expandCollapse(id) { 
	var strId = String(id);
	if (document.getElementById) { 
		if (document.getElementById(id).style.display == "none"){
			document.getElementById("anchor"+ strId).innerHTML = "";	
			document.getElementById(id).style.display = 'inline';
			filter(("img"+id),'imgin');						
			treetable.grid.rowHeightChanged(treetable.grid.expandoRowIndex);			
			listOfDivs[strId] = strId;;
			
			
		} else {
			document.getElementById("anchor"+ strId).innerHTML = "...";	
			document.getElementById(id).style.display = 'none';			
			filter(("img"+id),'imgout');			
			treetable.grid.rowHeightChanged(treetable.grid.expandoRowIndex);			
			delete listOfDivs[strId];
		
		}	
	}
}


function setExclusionReson(jsonStore, includedText, excludedText, item, reasons, exclusionReason, expand, sblExpand, imgSrc){
	var result;
 	if(exclusionReason){	
		var exclusionComment = jsonStore.getValue(item, "exclusionComment");
		if((excludedText.length + reasons[exclusionReason].length + exclusionComment.length) > 75){
			var idDiv = jsonStore.getValue(item, "productInventoryId");
			result = excludedText; 
			result += reasons[exclusionReason].substr(0,74).replace(":","");	
			result += "<div style='display:" + expand + "; text-align:left;' id=" + idDiv +" class = 'hidden'>";
			result += " " + reasons[exclusionReason].substr(74,reasons[exclusionReason].length).replace(":","");	//we want to get rid of ':' in this case			
			if(exclusionComment) result += ("&nbsp;(" + exclusionComment + ")");
			result += "</div>";
			result += "<a id=anchor" + jsonStore.getValue(item, "productInventoryId") + ">" + sblExpand + "</a>" ;
			result += "<img src='resources/images/arrow_" + imgSrc + ".png' name=img" + idDiv + " onClick='expandCollapse(" + idDiv + ")' width='16' height='16' border='0'>";			
		}else{
			result = excludedText + " " + reasons[exclusionReason].replace(":","");	//we want to get rid of ':' in this case			
			if(exclusionComment) result += ("&nbsp;(" + exclusionComment + ")");
		}			
	} else {
		result = includedText;
	} 
	return result;
}
