/*
 Licensed Materials - Property of IBM
 5724-T40 IBM License Metric Tool
 5725-C68 IBM Tivoli Asset Discovery for Distributed
 (C) Copyright IBM Corp. 2002, 2011.
 All Rights Reserved. US Government Users Restricted Rights - Use,
 duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 For more detailed help, refer to product manual.
 */

var quickFilter;
var treeTableFilters;
var sortColumn;
var sortIsDesc;
var sortFields;
var sortOrder='';
var treetable;
var jsonStore;
var lazyTreeModel;
var isSimpleSelected;
var instanceLevelColumnsShown;
var treetableFirstFetch;
var resizeAfterFetch=true;
var columnVisibility={};
var lastUpdateTime;

/* returns selectedColumnName if it is valid for current view; returns 1st selectable (default) columnName otherwise */
function getColumnForFilter(selectedColumnName){
	var selectable = false;
	for(var i=0; i<filterColumnList.length; i++){
		if(filterColumnList[i].columnName == selectedColumnName){
			selectable = true;
			break;
		}
	}
	if(selectable){
		return selectedColumnName;
	}else{
		return filterColumnList[0].columnName;
	}
}

/* clears and sets filter parameters taking into account columns available for current view type */
function setFilterParamsInQuery(mQuery){
	removeTreeTableColumnFiltersFromParams(mQuery);
	if(treeTableFilters && !isSoftInvDataRefreshNeeded()){
		var isFilterSet = false;
		for(columnName in treeTableFilters){
			//if this column is not selectable for current view type, set default column
			var columnForFilter = getColumnForFilter(columnName);
			mQuery[columnForFilter] = decodeURIComponent(treeTableFilters[columnName]);
			isFilterSet = true;
		}
		if(!isFilterSet && !!mQuery.filterText && mQuery.filterText!=""){
			//filter set 1st time on STG view - filter by default column
			mQuery[filterColumnList[0].columnName] = mQuery.filterText; 
		}
	}
}

function createTreeTable(initialH){
	checkLastUpdateTime(false);//reset last update time
	
	var firstCreation = !jsonStore;
	instanceLevelColumnsShown = !hideEmptyColumns;
	if(!jsonStore){
		jsonStore = new dojox.data.QueryReadStore({url:resourceBundle.contextPath+"/JsonRenderServlet?sessionId=" + sessionId, clearOnClose: true});
	}
	if(firstCreation){
		//the change of getValue below is to disable some unwanted console tracing from QueryReadStore
		var originalGetValue = dojo.hitch(jsonStore, jsonStore.getValue);
		jsonStore.getValue = function(item, attribute, defaultValue) {
			if(!this.hasAttribute(item, attribute)){
				return item.i[attribute]?item.i[attribute]:""; //return "" if there is null or undefined
			} else {
				return originalGetValue(item, attribute, defaultValue);
			}
		};
	}
	
	var initialQuery = {target: "tree", viewType: resourceBundle.viewType, startDate: resourceBundle.startDate, endDate: resourceBundle.endDate, 
			confMin: confMin, confMax: confMax, sortColumn: sortColumn, sortIsDesc: sortIsDesc, filterText: quickFilter};
			
	if(lazyTreeModel){
		//use current query but add missing properties
		lazyTreeModel.query = dojo.mixin(initialQuery, lazyTreeModel.query);
		lazyTreeModel.query.target = "tree"; 
		lazyTreeModel.query.startDate = resourceBundle.startDate;
		lazyTreeModel.query.endDate = resourceBundle.endDate;
		lazyTreeModel.query.viewType = resourceBundle.viewType;
		setFilterParamsInQuery(lazyTreeModel.query);
		
	}else{
		setFilterParamsInQuery(initialQuery);
		lazyTreeModel = new dojox.grid.LazyTreeGridStoreModel({store: jsonStore, serverStore: true, query: fetchSwinvData?initialQuery:{target:"empty"}});
	}
	
	//Presorting column based on values stored in session
	if(sortColumn != 99){
		var columnId = (sortColumn)-1;
		sortFields = [{ 
			attribute:columnId.toString(),
			descending:sortIsDesc
		}];	
	}else{
		sortFields = null;
	}
	
	
	treetable = new dojoe.treetable.TreeTable({
		width: '99%',
		height: initialH ? initialH : '70%',
		enableResize: true,
		menu: rowMenu,
		toolbarVisible: true,
		toolbarOptions : {
			refreshIcon: false,
			refreshMenu: false,
			selectAllIcon: true,
			onlyDeselectAllIcon: true,
			expandAllIcon : true,
			clearSortIcon: false,
			configureTreeTableIcon: true,
			actionMenu: true,
			selectAllMenu: false,
			expandAllMenu : false,
			clearSortMenu: false,
			configureTreeTableMenu: false,
			quickFilterVisible: true,
			showQuickFilterButton: true
		},
		gridParams: {
			autoWidth: false,//horizontal scrollbar	
			queryOptions: {"deep": true},
			id: "id",
			jsId: "id",
			rowsPerPage: 80,
			sortChildItems: true,
			lazyModel: true,
			columnReordering: true,
			rowSelector: false,
			treeModel: lazyTreeModel,
			indirectSelection: false,
			enableColumnReorder: false,
			structure: layout,
			sortFields: sortFields,
			storeType: true,
			selectionMode: 'extended',
			filter: { 
				quickFilter: true, 
				showQuickFilterButton: true,
				showHierarchy: true,
				isServerSide : true, 
				setupFilterQuery: 
					function(commands, request) {
						var filter = commands.filter;
						console.info("commands", commands);
						request.query.viewType = resourceBundle.viewType;
						request.query.startDate = resourceBundle.startDate; 
						request.query.endDate = resourceBundle.endDate;
						request.query.target = "tree";
						request.query.confMin = confMin;
						request.query.confMax = confMax;
						
						if(!isSoftInvDataRefreshNeeded()){
							setFilterParamsInQuery(request.query);
						}

						if (commands.enable && filter) {
							this._condition = request.query;
						}
						else {
							this._condition = null;
						}
					}
			},
			getSortProps: function(){ 
				//override default Dojo function to use column index instead column name
				//in request query - to be able to distinguish columns named "_item" 
				var sortIdx = this.getSortIndex()+"";	
				var c = this.getCell(sortIdx);
				if(!c){
					if(this.sortFields){
						return this.sortFields;
					}
					return null;
				}else{
					var desc=c["sortDesc"];
					var si=!(this.sortInfo>0);
					if(typeof desc=="undefined"){
						desc=si;
					}else{
						desc=si?!desc:desc;
					}							
					return [{attribute:sortIdx,descending:desc}];
				}
			},
			getSortIndex: function(inSortInfo){
				//override default Dojo function to use column index instead column name
				if(this.sortInfo === 0 && this.sortFields){
					var columnField = this.sortFields[0].attribute;
					var sortIdx = parseInt(columnField)+1;
					this.sortInfo = this.sortFields[0].descending ? -sortIdx : sortIdx;
				}
				inSortInfo = inSortInfo == undefined ? this.sortInfo : inSortInfo;
				return Math.abs(inSortInfo) - 1; // Integer
			},
			_render: function(){
				//override default Dojo function to render less rows per scroll 
				if(this.domNode.parentNode){
					//last argument was changed to '20', default number was equal to 'rowsPerPage'
					this.scroller.init(this.get('rowCount'), this.keepRows, 20); 
					this.prerender();
					this._fetch(0, true);
				}
			},
			_updateChangedRows: function(start){
				//override default Dojo function to render less rows per scroll (use 'scroller.rowsPerPage', default is 'rowsPerPage')
				dojo.forEach(this.scroller.stack, function(p){
					if(p * this.scroller.rowsPerPage >= start){
						this.updateRows(p * this.scroller.rowsPerPage, this.scroller.rowsPerPage);
					}else if((p + 1) * this.scroller.rowsPerPage >=  start){
						this.updateRows(start, (p + 1) * this.scroller.rowsPerPage - start + 1);
					}
				}, this);
			}
			

		}
	}, 'TreeTable_Programmatic');
		
	//apply quick filter from session
	if(quickFilter != undefined && quickFilter != null && quickFilter != ''){
		treetable.setFilter(decodeURIComponent(quickFilter));	
	}
	
	treetable.startup();
	treetable.grid.canSort = function(col){
		if(treetable.grid._loading) return false;
		if (treetable.gridParams.indirectSelection == true) {
			if(Math.abs(col) == 2||Math.abs(col)==4){ 
				return true; 
			} else { 
				return false; 
			}
		} else {
			if(Math.abs(col) == 1||Math.abs(col)==3){ 
				return true; 
			} else { 
				return false; 
			}
		}
	};
	
	//Actions menu hover text
	treetable._toolbar.toolbarFirstRow.lastChild.firstChild.title = resourceBundle.LabelDescriptionDetailed;
	
	if(firstCreation){
		connections.push(
				dojo.connect(treetable.grid.store, "fetch", function(request){
					// scrolling with fetching data, skip getting the 1st page as it is already handled
					if(request.start>0){
						checkLastUpdateTime(true);// check modification date and display warning if needed
					}
				})
		);	
	}	

	connections.push(
			dojo.connect(treetable, "showRowContextMenu", function(e) { treetable.onContextMenuEvtObj = e; })
	);
		
	connections.push(
			dojo.connect(treetable, "refresh", prepareStoreRefresh)
	);
	
	connections.push(
			dojo.connect(treetable.grid, "onSelectionChanged", onClickTreeTableHandler)
	);
	
	connections.push(
		dojo.connect(treetable.grid, "sort", function(){
			checkLastUpdateTime(true);//check modification date and display warning if needed
			saveSortOrder(treetable.grid.sortInfo);
			if(hideEmptyColumns){
				showInstanceLevelColumns(true);
			}
			onClickTreeTableHandler();//enable/disable actions
			treetable.grid._refresh(true);
		})
	);
		
	var originalWrapStore = dojo.hitch(treetable._toolbar.quickFilter,treetable._toolbar.quickFilter.wrapStore);
	treetable._toolbar.quickFilter.wrapStore = function(){
		setTreeTableColumnFilters();
		return originalWrapStore();
	};

	connections.push(
		dojo.connect(treetable._toolbar.quickFilter, "wrapStore", function(){
			checkLastUpdateTime(true);//check modification date and display warning if needed
			saveQuickFilter(getQuickFilterText());
			if(hideEmptyColumns){
				showInstanceLevelColumns(true);
			}		
			onClickTreeTableHandler();//enable/disable actions
		})
	);
	
	var originalClearFilter = dojo.hitch(treetable._toolbar.quickFilter,treetable._toolbar.quickFilter._clearFilter);
	treetable._toolbar.quickFilter._clearFilter = function(){
		//this is necessary to clear filter correctly
		treetable._toolbar.quickFilter.filterText='';
		treeTableFilters = {};		
		setTreeTableColumnFilters();
		removeTreeTableColumnFiltersFromParams(lazyTreeModel.query);		
		return originalClearFilter();
	};
	
	connections.push(
		dojo.connect(treetable._toolbar.quickFilter, "_clearFilter", function(){
			checkLastUpdateTime(true);//check modification date and display warning if needed
			saveQuickFilter(getQuickFilterText());
			if(hideEmptyColumns){
				showInstanceLevelColumns(true);
			}		
			onClickTreeTableHandler();//enable/disable actions
		})
	);
	
	connections.push(
		dojo.connect(treetable.grid, "onRowContextMenu", function(item) {
			if (!treetable.grid.selection.isSelected(item.rowNode.gridRowIndex)) {
				treetable.grid.selection.clear();
				treetable.grid.selection.setSelected(item.rowNode.gridRowIndex, true);
				onClickTreeTableHandler();//enable/disable actions
			};
		})
	);
		
	treetableFirstFetch = true;	
	resizeAfterFetch = true;
	connections.push(
		dojo.connect(treetable.grid,"_onFetchComplete", function(items){
			if(resizeAfterFetch){
				setTimeout(function(){
					//needed to resize correctly if messages are displayed,this should happen after showing initial messages
					resizeTreeTable();
				},1000);
				
				resizeAfterFetch = false;
			}
			if(treetableFirstFetch){				 
				//always get settings from session - table may be being reloaded
				treetableFirstFetch = false;
				loadColumnVisibility(!fetchSwinvData);
				fetchSwinvData=true;
			}
			if(!!items && (items.length<1 || 
					(items[0].i.level=='product' && resourceBundle.viewType != 'STG_PRODUCTS')||
					(items[0].i.level=='release' && resourceBundle.viewType == 'STG_PRODUCTS'))){	
				dojo.html.set(dojo.byId("InfoDisplayedProducts"),
						formatLabel(resourceBundle.viewType=='STG_PRODUCTS'?resourceBundle.InfoDisplayedReleases:resourceBundle.InfoDisplayedProducts, 
								""+(items.length>0 ? items[0].i.nmbOfAllRows:0)));
			}
			treetable.grid.scroller.rowHeightChanged(treetable.grid.scroller.lastVisibleRow);
		})
	);
	
	connections.push(
		dojo.connect(treetable.grid,"_onFetchError", function(){
			resizeTreeTable();//there is always an error msg
			resizeAfterFetch = true;//resize when next _onFetchComplete
			//display treetable layout correctly when fetch error occurred  
			if(treetableFirstFetch){
				//always get settings from session - table may be being reloaded
				treetableFirstFetch = false;
				loadColumnVisibility(true);
				fetchSwinvData=true;
			}
		})
	);
	
	treetable.grid.onFetchError = dojo.hitch(this, onFetchErrorHandler);

	connections.push(
		dojo.connect(treetable.grid,"toggleLoadingClass", function(isGridBeforeUpdate){
			//expanding or collapsing
			if(!isGridBeforeUpdate){
				checkLastUpdateTime(true);
				if(hideEmptyColumns){
					setTimeout(function(){
						var firstRowId=treetable.grid.scroller.firstVisibleRow;
						if(showInstanceLevelColumns()){
							//focus lost after grid.setStructure - set it on the 1st column in expanded row
							var cell=treetable.grid.getCell(0);
							treetable.grid.focus.setFocusCell(cell, treetable.grid.expandoRowIndex);
							treetable.grid.scrollToRow(firstRowId);
						}
					},100);
				}
				
				if(isInstanceShown()){
					treetable.gridParams.structure[0].width = 30;
				}
				else{
					treetable.gridParams.structure[0].width = '100%';
				}
				
				onClickTreeTableHandler();//enable/disable actions
			}
		})
	);

	connections.push(
		dojo.connect(treetable._toolbar, "_collapseAll", function(){
			checkLastUpdateTime(true);//check modification date and display warning if needed
			if(hideEmptyColumns){
				showInstanceLevelColumns(true);
			}
			onClickTreeTableHandler();//enable/disable actions
		})
	);

	
	treetable.addToToolbar(createDynamicButton(),1,1);		
	createToolbarActions();	
	
	if(!isSoftInvDataRefreshNeeded()){
		createFilterComboBox();
	}
	
	var originalConfigureColumn = dojo.hitch(treetable._toolbar, treetable._toolbar._configureColumn);
	treetable._toolbar._configureColumn = function() {

		var idOffset = 1;
		if(treetable.gridParams.indirectSelection) {
			idOffset++;
		}		
		
		var instanceShown = hideEmptyColumns ? isInstanceShown() : true;
		var newCells = [];
		var mapping=[];
		var cells=treetable.grid.layout.cells;
		if(!instanceShown){
			for(var i=idOffset;i<cells.length;i++){
				if(!cells[i].instanceLevelOnly){
					mapping[newCells.length]=i-idOffset;
					newCells.push(cells[i]);
				}
			}
		}else{
			for(var i=idOffset;i<cells.length;i++){
				mapping[i-idOffset]=i-idOffset;
				newCells.push(cells[i]);
			}			
		}
		
		treetable.grid.layout.cells=newCells;
		var ccResult = originalConfigureColumn();
		treetable.grid.layout.cells=cells;
		
		treetable._toolbar.tableOptionsDialog.onOK = function() {
			var isQfSet = lazyTreeModel.query.filterText && (lazyTreeModel.query.filterText!=="");
			var shouldRefetchData = false;
			
			//TED code for onOK adjusted			
			var rowCount = this.enhancedGrid.rowCount;
			//this._reorderColumn();
			var params = 'target=setColumnVisibility&viewType=' + resourceBundle.viewType + '&columnVisibility=';
			
			for (var i = 0; i < rowCount; i++) {
				var selected = (columndata.items[i].hidden[0] == true);//adjusted to TED code
				var structureColumnId = mapping[i]+idOffset; 
									
				params += (mapping[i]+1) + ':' + selected + ',';
				var changed = (this.grid.structure[structureColumnId].hidden == selected);
				//if there is a value in QF and we show or hide a column that is filterable then we should refetch the data
				if(isSoftInvDataRefreshNeeded() && isQfSet && changed && this.grid.structure[structureColumnId].filter) {
					shouldRefetchData = true;
				}
				this.grid.structure[structureColumnId].hidden = !selected;
				columnVisibility[resourceBundle.viewType][structureColumnId] = selected + "";
			}

			var firstRowId=this.grid.scroller.firstVisibleRow;
			this.grid.setStructure(this.grid.structure); //refresh
			this.grid.scrollToRow(firstRowId);

			params = trimEndingComa(params);
			params = params + "&sessionId=" + sessionId;
			//save column visibility
			this.hide();			
			var progressDlg = showProgressDlgIndicator("columnVisibility", resourceBundle.ConfigureOptionsDialogTitle);
			sendServletRequest('POST', 'ActionServlet', params, function(){
				if (this.readyState == 4) {
					//do the same for success and failure
					progressDlg.destroyRecursive();
					if(shouldRefetchData) {
						refreshAndCollapseTreetable(true, false);//check modification date and display warning if needed
					}
				}
			});

			};
		return ccResult;
	};

	dojo.style(treetable._toolbar.toolbarFirstRow, "width", "100%");
	treetable.domNode.children[0].rows[1].vAlign = "top";

}

function createToolbarActions() {
	
	var toolbarMenuItem1 = new dijit.MenuItem( {
		id : "toolbarMenuRelease",
		label : resourceBundle.MenuBundleReleases,
		disabled : true,
		iconClass: "claro assignToProduct",
		onClick : function(item) {
			showBundleFromPrdDialog();
		}
	});
	var toolbarMenuItem2 = new dijit.MenuItem( {
		id : "toolbarMenuInstance",
		label : resourceBundle.MenuBundleInstances,
		disabled : true,
		iconClass: "claro reassignInstance",
		onClick : function(item) {
			showDialog();
		}
	});
	
	var toolbarMenuItem3 = new dijit.MenuItem( {
		id : "toolbarMenuConfirm",
		label : resourceBundle.MenuBundleConfirm,
		disabled : true,
		iconClass: "claro confirmInstance",
		onClick : function(item) {
			confirmSelected();
		}
	});
	
	var toolbarMenuItem4 = new dijit.MenuItem({
		id: "toolbarMenuInclude",
	    label: resourceBundle.MenuBundleInclude,
	    disabled: true,
	    iconClass: "claro include",
	    onClick: function(item){ 
			showExcludedTableDialog('true');
		}
	});
	
	var toolbarMenuItem5 = new dijit.MenuItem({
		id: "toolbarMenuExclude",
	    label: resourceBundle.MenuBundleExclude,
	    disabled: true,
	    iconClass: "claro exclude",
	    onClick: function(item){ 
	    	showExcludedTableDialog('false');
	 	}
	});
	
	var toolbarMenuItem6 = new dijit.MenuItem( {
		id: "toolbarMenuShare",
		label : resourceBundle.MenuBundleShareInstance,
		iconClass: "claro share",
		disabled : true,
		onClick: function(item){ 
			showShareDialog();
		}
	});
	
	toolbarMenuItem1._destroyOnRemove = true;
	toolbarMenuItem2._destroyOnRemove = true;
	toolbarMenuItem3._destroyOnRemove = true;
	toolbarMenuItem4._destroyOnRemove = true;
	toolbarMenuItem5._destroyOnRemove = true;
	toolbarMenuItem6._destroyOnRemove = true;
	
	treetable.addToActionList(toolbarMenuItem6);
	treetable.addToActionList(toolbarMenuItem5);
	treetable.addToActionList(toolbarMenuItem4);
	treetable.addToActionList(toolbarMenuItem3);
	treetable.addToActionList(toolbarMenuItem2);
	treetable.addToActionList(toolbarMenuItem1);
}


function loadColumnVisibility(showError) {	
	var grid = treetable.grid;
	var cols = treetable.grid.structure;
	for(viewType in layoutList){		
		//get visibility for all views to save them in session
		if(columnVisibility[viewType] == undefined || columnVisibility[viewType] == null){
			var data = getColumnVisibilityUrl(viewType);
			sendSaveColumnVisibility(grid, cols, data, viewType, viewType === resourceBundle.viewType, showError);

		}else{
			if(viewType === resourceBundle.viewType){
				setVisibility(columnVisibility[viewType], grid, cols, showError);
			}
		}
	}
}

function sendSaveColumnVisibility(grid, cols, data, viewType, isCurrentView, showError){
	sendServletRequest('POST', 'ActionServlet', data + "&sessionId=" + sessionId,  
		function(){
			//set visibility only for the current view
			if (this.readyState == 4){
				if(this.status == 200 && this.responseText) {				
					columnVisibility[viewType] = dojo.fromJson(this.responseText);
					if(isCurrentView){
						setVisibility(columnVisibility[viewType], grid, cols, showError);
					}
				} else {
					console.log('An error has occurred while loading column visibility. status=' + this.status + ', responseText=' + this.responseText);
				}
		}
	});
}


function setVisibility(visibility,grid,cols,showError){
	var idOffset = 0;
	if(treetable.gridParams.indirectSelection) {
		idOffset++;
	}
	for(var columnId in visibility) {
		var structureColId = parseInt(columnId)+idOffset;
		var columnHidden = (visibility[columnId] === 'false') || (hideEmptyColumns && cols[structureColId].instanceLevelOnly);
		cols[structureColId].hidden = columnHidden; 
	}
	grid.setStructure(grid.structure); //refresh structure
	if(showError){
		grid.showMessage(grid.errorMessage);
	}

}

function getDefaultVisibilityAsString(viewLayout) {
	if(viewLayout==undefined || viewLayout==null){
		viewLayout = layout;
	}
	var result = '';
	for(var i = 1; i < viewLayout.length; i++) {
		result += i;
		result += ':' + !viewLayout[i].hiddenDefault;
		result += ',';
	}
	result = trimEndingComa(result);
	return result;
}

function getColumnFilterMappingAsString(viewLayout) {
	if(viewLayout==undefined || viewLayout==null){
		viewLayout = layout;
	}
	var result = '';
	for(var i = 1; i < viewLayout.length; i++) {
		if(viewLayout[i].filter) {
			result += i;
			result += ':' + viewLayout[i].filter;
			result += ',';
		}
	}
	result = trimEndingComa(result);
	return result;
}

function trimEndingComa(string) {
	var result = string;
	if(result.substr(-1) === ',') result = result.substring(0, result.length - 1);
	return result;
}


function getColumnVisibilityUrl(viewType){
	var viewLayout = layoutList[viewType];
	return 'target=getColumnVisibility&viewType=' + viewType + 
	'&defaultVisibility=' + getDefaultVisibilityAsString(viewLayout) + '&columnFilterMapping=' + getColumnFilterMappingAsString(viewLayout);
}

function saveSortOrder(sort) {
	var params = 'target=setSortOrder&sortOrder=' + sort  + "&sessionId=" + sessionId;
	sortOrder=sort+"";
	sortIsDesc = (sortOrder.indexOf("-")==0);
	sortColumn = sortIsDesc ? sortOrder.substring(1) : sortOrder;

	var columnId = parseInt(sortColumn)-1;
	sortFields = [{ 
		attribute:columnId+"",
		descending:sortIsDesc
	}];	

	buildDownloadCSVLink('DownloadCSV');
	sendServletRequest('POST', 'ActionServlet', params, null);
}

function getQuickFilterText() {
	if(treetable._toolbar.quickFilter.filterText == undefined || treetable._toolbar.quickFilter.filterText == null){
		return "";
	} else {
		// escape special characters to avoid xss
		var filterTemp = encodeURIComponent(treetable._toolbar.quickFilter.filterText); 
		return filterTemp;
	}
}

function getQuickFilterTextNotEncoded() {
	if(treetable._toolbar.quickFilter.filterText == undefined || treetable._toolbar.quickFilter.filterText == null){
		return "";
	} else {
		return treetable._toolbar.quickFilter.filterText; 
	}
}

function saveQuickFilter(filterText) {
	var params = 'target=setQuickFilter&quickFilter=' + filterText + "&sessionId=" + sessionId;
	quickFilter=filterText;	
	
	if(!isSoftInvDataRefreshNeeded()){
		var columnFilterParam = buildColumnFilterParameterAsString(false);
		if(columnFilterParam != "")
			params += "&" + columnFilterParam;
	}
	
	
	buildDownloadCSVLink('DownloadCSV');
	sendServletRequest('POST', 'ActionServlet', params, null);
}

function isInstanceShown(){
	for(var i=0;i<treetable.getRowCount();i++){
		var item = treetable.grid._by_idx[i];//avoid lazy loading of page - use grid cache
		if (null!=item && 'instance' === item.item.i['level']) {
			return true;
		}
	}
	return false;
}

function showInstanceLevelColumns(afterCollapse){
	var visible = afterCollapse ? false : isInstanceShown();
	if(instanceLevelColumnsShown != visible){//avoid hiding/unhiding if not necessary
		var cols = treetable.grid.structure;
		var changed = false;		
		var result = [];		
		var idOffset = 0;
		if(treetable.gridParams.indirectSelection) {
			idOffset++;
		}		
		
		for(var columnId in columnVisibility[resourceBundle.viewType]) {
			var structureColumnId = parseInt(columnId)+idOffset;
			var columnHidden = (columnVisibility[resourceBundle.viewType][columnId] === 'false' || (!visible && cols[structureColumnId].instanceLevelOnly)); 
			
			//show or hide but do not modify session
			var oldValue = cols[structureColumnId].hidden;
			var newValue = columnHidden; 
			
			if(oldValue != newValue) {
				cols[structureColumnId].hidden = newValue;
				changed = true;
			}
		}
		
		if(changed){
			treetable.grid.setStructure(treetable.grid.structure); //refresh structure
		}
		instanceLevelColumnsShown = visible;
		return changed;
	}
}


function onClickTreeTableHandler(item) {
	var releaseSelected = 0;
	var numberOfInstancesSelected = 0;
	var isComplexSelected = false;
	isSimpleSelected = false;
	var productSelected = false;
    var confirmedReleasesSelected = true;
	var selectedRows = treetable.grid.selection.getSelected();

	for (i=0; i<selectedRows.length; i++) {
		//skip not fetched rows
		if(!!selectedRows[i]){//not null,not undefined
			var level = jsonStore.getValue(selectedRows[i], 'level');
			if (level === 'instance'){
				numberOfInstancesSelected++;
				if (jsonStore.getValue(selectedRows[i], 'isSimple') === 'false') {
					isComplexSelected = true;
				} else {
					isSimpleSelected = true;
				}
			}
			if (level === 'release'){
				releaseSelected++;
				selectedReleaseId = jsonStore.getValue(selectedRows[i],'id').split('_')[0];
				selectedReleaseName = jsonStore.getValue(selectedRows[i],'productReleaseComponent');
                if (jsonStore.getValue(selectedRows[i],'confidence') != '100') {
                  confirmedReleasesSelected = false;
                }
			}
			if (level === 'product'){
				productSelected = true;
			}
		}
	}

	var menuInstances = dijit.byId("menuInstance");
	var menuConfirm = dijit.byId("menuConfirm");
	var menuExclude = dijit.byId("menuExclude");
	var menuInclude = dijit.byId("menuInclude");
	var menuRelease = dijit.byId("menuRelease");
	var menuShare = dijit.byId("menuShare");
	var toolbarMenuInstances = dijit.byId("toolbarMenuInstance");
	var toolbarMenuConfirm = dijit.byId("toolbarMenuConfirm");
	var toolbarMenuExclude = dijit.byId("toolbarMenuExclude");
	var toolbarMenuInclude = dijit.byId("toolbarMenuInclude");
	var toolbarMenuRelease = dijit.byId("toolbarMenuRelease");
	var toolbarMenuShare = dijit.byId("toolbarMenuShare");

	treetable.disableMenuItem(menuInstances);
	treetable.disableMenuItem(menuConfirm);
	treetable.disableMenuItem(menuRelease);
	treetable.disableMenuItem(menuShare);
	treetable.disableMenuItem(menuExclude);
	treetable.disableMenuItem(menuInclude);
	treetable.disableMenuItem(toolbarMenuInstances);
	treetable.disableMenuItem(toolbarMenuConfirm);
	treetable.disableMenuItem(toolbarMenuRelease);
	treetable.disableMenuItem(toolbarMenuShare);
	treetable.disableMenuItem(toolbarMenuExclude);
	treetable.disableMenuItem(toolbarMenuInclude);
	
	updateTime = [];
	prod_inv_id = [];
	prod_inv_id_complex = [];
    releases = [];
	nmbOfInstancesInSelectedReleases = 0;    
	updateTime_complex = [];
	
	if (numberOfInstancesSelected > 0 && !productSelected && releaseSelected==0) {
		if(isComplexSelected) {
			treetable.enableMenuItem(menuInstances);
			treetable.enableMenuItem(menuConfirm);
			treetable.enableMenuItem(toolbarMenuInstances);
			treetable.enableMenuItem(toolbarMenuConfirm);
		}
		
		treetable.enableMenuItem(menuExclude);
		treetable.enableMenuItem(menuInclude);
		treetable.enableMenuItem(toolbarMenuExclude);
		treetable.enableMenuItem(toolbarMenuInclude);
	}
	
	if(releaseSelected == 1 && numberOfInstancesSelected==0 && !productSelected){
		treetable.enableMenuItem(menuRelease);
		treetable.enableMenuItem(toolbarMenuRelease);
    }
	
    if (releaseSelected>0 && !productSelected && numberOfInstancesSelected==0) { 
        if (!confirmedReleasesSelected) {
          treetable.enableMenuItem(menuConfirm);
          treetable.enableMenuItem(toolbarMenuConfirm);
        }
		treetable.enableMenuItem(menuExclude);
		treetable.enableMenuItem(toolbarMenuExclude);
		treetable.enableMenuItem(menuInclude);
		treetable.enableMenuItem(toolbarMenuInclude);
		treetable.enableMenuItem(menuInstances);
		treetable.enableMenuItem(toolbarMenuInstances);


        for (i=0; i<selectedRows.length; i++) {
		 if (null != jsonStore.getValue(selectedRows[i],'id') && 'release'== jsonStore.getValue(selectedRows[i],'level')) 
                  {
                    releases.push(jsonStore.getValue(selectedRows[i],'id').split('_')[0]);
					nmbOfInstancesInSelectedReleases += parseInt(jsonStore.getValue(selectedRows[i],'numberOfAllInstances'));
                  }
	        }
	} else {
		releases =[];       
		nmbOfInstancesInSelectedReleases = 0;    
	}
	
	if (numberOfInstancesSelected == 1 && !isSimpleSelected && !productSelected && releaseSelected==0) {
		treetable.enableMenuItem(menuShare);
		treetable.enableMenuItem(toolbarMenuShare);
	}

	for (i=0; i<selectedRows.length; i++) {
		if(!!selectedRows[i]){//not null,not undefined
			if (null != jsonStore.getValue(selectedRows[i],'productInventoryId')) {
				prod_inv_id.push(jsonStore.getValue(selectedRows[i],'productInventoryId'));
				updateTime.push(jsonStore.getValue(selectedRows[i],'updateTime'));
				if(jsonStore.getValue(selectedRows[i],'isSimple') === 'false') {//skip simple instances
					prod_inv_id_complex.push(jsonStore.getValue(selectedRows[i],'productInventoryId'));
					updateTime_complex.push(jsonStore.getValue(selectedRows[i],'updateTime'));
				}
			}
		}
	}
	
};


function checkLastUpdateTime(showMsg){
	if(!showMsg || !isSoftInvDataRefreshNeeded()){
		var warning = dijit.byId(resourceBundle.warningDataChanged.msgId);
		if(warning!=undefined && warning!=null){
			warning.destroyRecursive();//destroy the msg and table row
		}
	}
	if(isSoftInvDataRefreshNeeded()){
		sendServletRequest('POST', 'ActionServlet', 'target=getLastUpdate&sessionId=' + sessionId, function(){
			if (this.readyState == 4){
				if(this.status == 200) {
					if(this.responseText && this.responseText!==''){
						var response = dojo.fromJson(this.responseText);
						if(showMsg){
							if(response.date !== lastUpdateTime){
								showMessage(resourceBundle.warningDataChanged.msgId, resourceBundle.warningDataChanged.msgText, true);
							}
						}else{
							lastUpdateTime = response.date;
						}
					}
				}else{
					onFetchErrorHandler(this);
				}
			}
		});
	}
}

//In this method do the needed pre setting for the particular store to refresh
function prepareStoreRefresh(){
	var treetable= dijit.byId("TreeTable_Programmatic");
	var usedstore = treetable.grid.store;
	if(usedstore.save) usedstore.save();
	usedstore.close();
}



//column filter section

function createFilterComboBox(){
	if(dijit.byId("columnFilterCombobox")){
		return;
	}

		var options = new dojo.data.ItemFileWriteStore({
			data: {
				identifier : "columnName",
				label : "name",
				items : filterColumnList
			}
		});
		
		//if no filter applied, select default item (software name)
		var initialFilterColumn = filterColumnList[0].columnName;
		if(treeTableFilters!=undefined && treeTableFilters != null)
			for(var columnName in treeTableFilters){
				initialFilterColumn = columnName;
				break;
			}
		
		var columnFilterCombobox = new dijit.form.Select({
			id : "columnFilterCombobox",
			store : options,
			sortByLabel: false,
			value : initialFilterColumn,//initialFilterColumn,
			style : "margin-top: 0px; width: 100%; height: 23px; "
		});
		
		columnFilterCombobox.startup();
		
		var quickFilterDomObject = dijit.byId(treetable._toolbar.quickFilter.id).domNode;
		quickFilterDomObject.style.minWidth="15em";
		quickFilterDomObject.style.width="100%";
		
		var newCol = dojo.create("td", {align:"right",height:"100%"});
		dojo.place(newCol,quickFilterDomObject.parentNode.parentNode,dojo.isIE?1:2);
		dojo.place(columnFilterCombobox.domNode,newCol,"first");
		
	}

/* read values from quickFilter and columnFilter combobox and write them to 'treeTableFilters' variable */
function setTreeTableColumnFilters(){
	var columnFilterCombobox = dijit.byId("columnFilterCombobox");
	if(columnFilterCombobox){
		var columnName = columnFilterCombobox.get('value');
		
		var filterText = getQuickFilterText();
		treeTableFilters = {};
		
		if(filterText != null && filterText != undefined &&  filterText != "")
			treeTableFilters[columnName] = filterText;
	}else{
		//STG view - update filters for other views
		var filterText = getQuickFilterText();
		if(filterText == null && filterText == undefined){
			filterText = "";
		}
		if(treeTableFilters){
			for(var columnName in treeTableFilters){
				treeTableFilters[columnName] = filterText;
			}
		}
	}
}

/* columnFilter may change between actions, so the old one should be removed from params passed to JsonRenderServlet */
function removeTreeTableColumnFiltersFromParams(/*map*/ params){
	var pattern = "_filter";
	for(var key in params){
		var index = key.indexOf(pattern);
		if(index != -1 && index == key.length - pattern.length){ //key matched to stinrg "_filter"
			delete params[key];
		}
	}
}

function /*string*/ buildColumnFilterParameterAsString(/*booleans*/ decode){
	var params = "";
	var isFilterSet = false;
	if(!isSoftInvDataRefreshNeeded() && treeTableFilters != undefined && treeTableFilters != null){	//add column filter to query
		for(var column in treeTableFilters){
			var columnForFilter = getColumnForFilter(column);
			params += '&' + columnForFilter + '=' + (decode?decodeURIComponent(treeTableFilters[column]):treeTableFilters[column]);
			isFilterSet = true;
		}
		if(!isFilterSet && !!quickFilter && quickFilter!=""){
			//filter set 1st time on STG view - filter by default column
			params += '&' + filterColumnList[0].columnName + '=' + (decode?quickFilter:decodeURIComponent(quickFilter));
		}
	}
		
	return params.substring(1); //substring: ommit the first '&'
}

