connect to tlma%

update ADM.CONTROL set VALUE='7.5.0.111' WHERE NAME='DATABASE_VERSION'%

insert into
  lic.RES_CONF_KEY_REL
 select distinct
   TYPE, 
   CONF_KEY_ID,
   '7.5.0.111' as version,
   VALUE_RANGE_MAX,
   VALUE_RANGE_MIN
 from 
   lic.RES_CONF_KEY_REL
 where
   version in
     ('7.5.0.10','7.5.0.14','7.5.0.15','7.5.0.16','7.5.0.17','7.5.0.18','7.5.0.19','7.5.0.110')
   and not exists
     (select * from lic.RES_CONF_KEY_REL where version = '7.5.0.111')%
  
-------------------------------------------------------------------------------

CREATE PROCEDURE ADM.CREATE_TABLE_IF_NOT_EXISTS(in SCHEMA_NAME char(40), in TABLE_NAME char(40), in COLUMNS_DEFINITION varchar(920))
	BEGIN
		DECLARE numRecords INT DEFAULT 0;
		DECLARE stmt VARCHAR(1000);

		SELECT COUNT(*) INTO numRecords
		FROM SYSCAT.TABLES 
		WHERE TABSCHEMA = SCHEMA_NAME AND TABNAME = TABLE_NAME;
			
		SET stmt = 'CREATE TABLE ' CONCAT SCHEMA_NAME CONCAT '.' CONCAT TABLE_NAME CONCAT '(' CONCAT COLUMNS_DEFINITION CONCAT ')';
		IF numRecords = 0 THEN
			PREPARE prep_stmt FROM stmt;
			EXECUTE prep_stmt;
		END IF;
	END%

-- if LDOMs are ported to 7.2.2 the table could exist in database
CALL ADM.CREATE_TABLE_IF_NOT_EXISTS(
	'ADM',
	'SOLARIS_PARTIAL_VM',
	'AGENT_ID BIGINT NOT NULL, NAME VARCHAR(192) NOT NULL, IS_GLOBAL SMALLINT NOT NULL, CAPACITY INTEGER NOT NULL, CAP_IN_CORES INTEGER NOT NULL, SP_NAME VARCHAR(192), SP_CAPACITY INTEGER, SP_CAP_IN_CORES INTEGER, SERIAL_NUMBER VARCHAR(192) NOT NULL'
)%

DROP PROCEDURE ADM.CREATE_TABLE_IF_NOT_EXISTS%

grant select, insert, delete, update, alter on ADM.SOLARIS_PARTIAL_VM to user TLMSRV%

comment on table ADM.SOLARIS_PARTIAL_VM is
    'The table stores information about local zones/global zones on logical domain'%
comment on column ADM.SOLARIS_PARTIAL_VM.AGENT_ID is
    'Agent identifier'%
comment on column ADM.SOLARIS_PARTIAL_VM.NAME is
    'The name of the layer where agent is installed (Lpar->LparID)'%
comment on column ADM.SOLARIS_PARTIAL_VM.IS_GLOBAL is
    'Indicates whether the scan was performed by the agent on global zone logical domain'%
comment on column ADM.SOLARIS_PARTIAL_VM.CAPACITY is
    'Capacity of the zone where agent is installed'%
comment on column ADM.SOLARIS_PARTIAL_VM.CAP_IN_CORES is
    'Capacity in cores of the zone where agent is installed'%
comment on column ADM.SOLARIS_PARTIAL_VM.SP_NAME is
    'Name of the shared pool or null if shared pool was not defined'%
comment on column ADM.SOLARIS_PARTIAL_VM.SP_CAPACITY is
    'Capacity of the shared pool or -1 if shared pool was not defined'%
comment on column ADM.SOLARIS_PARTIAL_VM.SP_CAP_IN_CORES is
    'Capacity in cores of the shared pool or -1 if shared pool was not defined'%
comment on column ADM.SOLARIS_PARTIAL_VM.SERIAL_NUMBER is
    'Serial number of LDOM or node if LDOM was not defined'%

disconnect current%
