connect to tlma%

--
--  using procedure below - due to lack of 
-- 'create or replace view' support in DB2 9.1 
--
create procedure CUSTOM.DROP_VIEW_IF_EXISTS(in NAME char(100))
	begin
	declare STMT char(250);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = ' DROP VIEW ' concat  NAME;
	prepare S1 from STMT;
	execute S1;
	end%

--
-- drop current version
-- 
call CUSTOM.DROP_VIEW_IF_EXISTS('CUSTOM.AGENT_SCAN_HISTORY_V')%

--
-- replace definition 
--
CREATE view CUSTOM.AGENT_SCAN_HISTORY_V
(ID, AGENT_ID,AGENT_HOSTNAME, SCAN_SCHEDULE_DATE,SCAN_GROUP,AGENT_ERROR_STATUS_CODE,AGENT_ERROR_STATUS, SW_SCAN_HISTORY_ID)
AS
SELECT AGENT_SCAN_HISTORY.ID, 
	   AGENT_SCAN_HISTORY.AGENT_ID AS AGENT_ID,
  	   AGENT.HOSTNAME AS AGENT_HOSTNAME, 
  	   SW_SCAN_HISTORY.SCHEDULE_DATE AS SCAN_SCHEDULE_DATE,
  	   DIVISION.NAME AS SCAN_GROUP,
  	   AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS AS AGENT_ERROR_STATUS_CODE,
		  CASE
		    WHEN AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS = 0 THEN 'Missing scan (agent problem - possibly agent not connected)'
		    WHEN AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS = -1 THEN 'Missing scan (server problem - possibly server down)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 32768, 2) > 0 THEN 'Scan error (Local software scan configuration corrupted)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 16384, 2) > 0 THEN 'Scan error (Software catalog corrupted )'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 8192, 2) > 0  THEN 'Scan error (Local software scan failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 4096, 2) > 0  THEN 'Scan error (Remote software scan configuration corrupted)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 2048, 2) > 0  THEN 'Scan error (Remote software scan failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 1024, 2) > 0  THEN 'Scan error (Use setup failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 512, 2) > 0 THEN   'Scan error (Use snapshot failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 256, 2) > 0 THEN   'Scan error (Use report failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 128, 2) > 0 THEN   'Scan error (Hardware scan configuration file corrupted)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 64, 2) > 0  THEN   'Scan error (Hardware scan failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 32, 2) > 0  THEN   'Scan error (Full hardware scan configuration corrupted)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 16, 2) > 0  THEN   'Scan error (Full hardware scan failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 8, 2) > 0   THEN   'Scan error (Scheduler error)'	
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 4, 2) > 0   THEN   'Scan error (Self update failed)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS / 2, 2) > 0   THEN   'Scan error (Agent undefined error)'
		    WHEN MOD(AGENT_SCAN_HISTORY.AGENT_ERROR_STATUS,  2) > 0      THEN   'Scan internal error'
		    ELSE  'Unknown scan error'
		  END AS AGENT_ERROR_STATUS,
		  AGENT_SCAN_HISTORY.SW_SCAN_HISTORY_ID 
  FROM  ADM.SW_SCAN_HISTORY AS SW_SCAN_HISTORY 
       	LEFT JOIN  ADM.AGENT_SCAN_HISTORY AS AGENT_SCAN_HISTORY 
       		ON SW_SCAN_HISTORY.ID = AGENT_SCAN_HISTORY.SW_SCAN_HISTORY_ID 
        JOIN ADM.DIVISION_FULL_V AS DIVISION 
        	ON SW_SCAN_HISTORY.DIVISION_ID = DIVISION.ID 
        LEFT JOIN ADM.AGENT_FULL_DISTINCT_V AS AGENT 
        	ON AGENT_SCAN_HISTORY.AGENT_ID = AGENT.ID%
    

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."ID" IS
'History internal identifier (Primary key)'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."AGENT_ID" IS
'Identifier of agent'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."SW_SCAN_HISTORY_ID" IS
'Identifier from sw_scan_history (foreign key)'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."AGENT_HOSTNAME" IS
'Agent hostname or IP'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."SCAN_SCHEDULE_DATE" IS
'Scheduled scan date'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."SCAN_GROUP" IS
'Scan group name'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."AGENT_ERROR_STATUS_CODE" IS
'The status code of a software scan'%

COMMENT ON COLUMN "CUSTOM"."AGENT_SCAN_HISTORY_V"."AGENT_ERROR_STATUS" IS
'Error description'%

COMMENT ON TABLE "CUSTOM"."AGENT_SCAN_HISTORY_V" IS
'Stores failed or missing agent software scan history'%

--#pragma ignore -551
GRANT SELECT ON CUSTOM.AGENT_SCAN_HISTORY_V TO USER TLMSRV%

-- clean up 
drop procedure CUSTOM.DROP_VIEW_IF_EXISTS%

disconnect current%
