connect to tlma%

-- Description of columns returned by custom view CUSTOM.PROCESSOR_INFO_V
-- Summary of processors/cores information 
-- hostname - host name of guest operating system (virtual partition)
-- node_name - name of hardware node (physical server)
-- node_id - id of node
-- system_model - hardware model name of hardware node
-- platform - hardware platform of the node
-- processor_coreness - number of cores of the node matched in PVU table
-- processor_brand - processor brand name matched in PVU table
-- raw_processor_brand - processor brand in format, that is sent by the agent (may be NULL)
-- processor_vendor - processor vendor name matched in PVU table
-- raw_processor_vendor - processor vendor in format, that is sent by the agent (may be NULL)
-- processor_model - processor model matched in PVU table
-- raw_processor_model - processor model in format, that is sent by te agent (may be NULL)
-- no_active_sockets - number of active processor sockets on the node
-- no_active_cores_srv - number of active processor cores on the node
-- no_active_cores_srv_bios - number of active processor cores enabled in BIOS/OS (works only on x86 OS installed directly on node)
-- no_logical_processors - number of logical processors on the virtual partition (reported by OS)
-- no_partition_cores - number of processor cores assigned to the virtual partition
-- cpu_frequency -- processor unit frequency

create procedure ADM.DROP_IF_EXISTS(in NAME char(100))
	begin
	declare STMT char(250);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP ' concat NAME;
	prepare S1 from STMT;
	execute S1;
	end%

-- create a temp table to save existing select grants for the view
call ADM.DROP_IF_EXISTS('table ADM.FP_SAVE_GRANTS')%
create table ADM.FP_SAVE_GRANTS
(
   grant_cmd varchar(250)
)%

create procedure ADM.RESTORE_VIEW_ACCESS()
   begin
    declare STMT char(250);
    declare prep_stmt char(250);

    for v1 as c1 cursor for select grant_cmd from ADM.FP_SAVE_GRANTS
      do
         set STMT= grant_cmd;
         prepare prep_stmt from STMT;
         execute prep_stmt;
      end for;
   end%
   
   	
insert into adm.fp_save_grants (grant_cmd) select 'grant select on CUSTOM.PROCESSOR_INFO_V to user "' || grantee || '"' from sysibm.systabauth where tcreator='CUSTOM' and ttname='PROCESSOR_INFO_V' and selectauth in ('Y','G')%

call ADM.DROP_IF_EXISTS('view CUSTOM.PROCESSOR_INFO_V')%

CREATE VIEW CUSTOM.PROCESSOR_INFO_V
(
	hostname,
	node_name,
	node_id,
	system_model,
	platform,
	processor_coreness,
	processor_brand,
	raw_processor_brand,
	processor_vendor,
	raw_processor_vendor,
	processor_model,
	raw_processor_model,
	no_active_sockets,
	no_active_cores_srv,
	no_active_cores_srv_bios,
	no_logical_processors,
	no_partition_cores,
	cpu_frequency
)
AS
WITH  t_vm AS (SELECT id, base_layer_id, row_number () OVER (PARTITION BY base_layer_id ORDER BY depth) AS depth 
			  FROM custom.layer_v where (depth >= 0 AND (type <> 0 or PARENT_LAYER_ID is null )))
SELECT distinct hostname,
       node_name,
	   node_id,
       system_model,
       platform,
       processor_coreness,
       processor_brand,
	   raw_processor_brand,
       processor_vendor,
	   raw_processor_vendor,
       processor_model,
	   raw_processor_model,
       no_active_sockets,
       no_active_cores_srv,
	   no_active_cores_srv_bios,
       no_logical_processors,
       no_partition_cores,
       cpu_freq
FROM   (SELECT afv.hostname AS hostname,
			   afv.id as agent_id,
               scr.tag AS node_name,
			   scr.id as node_id,
               msm.qualifier AS system_model,
               scr.platform AS platform,
               pr.cpu_freq,
               CASE WHEN pt.id <> 1 THEN pt.type ELSE
                   CASE WHEN mo.qualifier IS NULL THEN 'One Core' ELSE adm.format_ptype (qual.ptype) END
               END AS processor_coreness,
               CASE WHEN pt.id <> 1 THEN pt.brand ELSE
                   CASE WHEN mo.qualifier IS NULL THEN 'Other' ELSE qual.brand END
               END AS processor_brand,
			   qual.brand AS raw_processor_brand,
               CASE WHEN pt.id <> 1 THEN pt.vendor ELSE
                   CASE WHEN mo.qualifier IS NULL THEN 'Other' ELSE qual.vendor END
               END AS processor_vendor,
			   qual.vendor AS raw_processor_vendor,
               CASE WHEN pt.id <> 1 THEN pt.model ELSE
                  CASE WHEN mo.qualifier IS NULL THEN 'All' ELSE qual.model END
               END AS processor_model,
			   qual.model AS raw_processor_model,
               CASE WHEN muc.quantity IS NULL THEN
                  (CASE WHEN m.quantity IS NULL THEN NULL ELSE (CASE WHEN qual.ptype IS NULL OR decimal(qual.ptype,7,2) = 0 THEN NULL ELSE ceil(m.quantity / (100 * decimal(qual.ptype,7,2))) END) END)
                  ELSE (CASE WHEN qual.ptype IS NULL OR decimal(qual.ptype,7,2) = 0 THEN NULL ELSE ceil(muc.quantity / (100 * decimal(qual.ptype,7,2))) END)                 
               END AS no_active_sockets,
               CASE WHEN muc.quantity IS NULL THEN
                  (CASE WHEN m.quantity IS NULL THEN NULL ELSE decimal(decimal(m.quantity,7,2) / 100,7,2) END)
                  ELSE decimal(decimal(muc.quantity,7,2) / 100,7,2)
               END AS no_active_cores_srv,
			   CASE WHEN m.quantity IS NULL THEN NULL
                  ELSE decimal(decimal(m.quantity,7,2) / 100,7,2)
               END AS no_active_cores_srv_bios,
               CASE WHEN ml.quantity IS NULL THEN 
                  CASE WHEN muc.quantity IS NULL THEN
                     (CASE WHEN m.quantity IS NULL THEN NULL ELSE decimal(decimal(m.quantity,7,2) / 100,7,2) END)
                  ELSE decimal(decimal(muc.quantity,7,2) / 100, 7,2)
               END ELSE decimal(ml.quantity,7,2) / 100 END AS no_logical_processors,
               CASE WHEN scr.platform in ('x86','x86_64','AMD64', 'amd64','i686','i586', 'i386', 'CLUSTER', 'IA32ONWIN64') and vmn.parent_layer_id is not null THEN
                  (CASE WHEN ml.quantity IS NULL THEN NULL ELSE decimal(decimal(ml.quantity,7,2) / 100,7,2) END)
                    ELSE CASE WHEN mv.quantity IS NULL THEN
                        (CASE WHEN m.quantity IS NULL THEN NULL ELSE decimal(decimal(m.quantity,7,2) / 100,7,2)  END)
                         ELSE decimal (decimal (mv.quantity,7,2) / 100, 7, 2)
						 
                         END
               END AS no_partition_cores
        FROM   custom.node_v scr
                --- start OS information on node
               INNER JOIN custom.layer_v vmn ON vmn.base_layer_id = scr.id
               INNER JOIN custom.layer_agent_rel_v avr ON vmn.id = avr.layer_id
                     AND avr.end_time = '9999-12-31 00:00:00.000'
                     AND avr.start_time < avr.end_time
               INNER JOIN custom.agent_v afv ON avr.agent_id = afv.id and afv.deleted_time is NULL
               LEFT JOIN custom.hw_physical_processor_v as pr on pr.computer_sys_id = avr.agent_id 
                --- end OS iformation on node
                --- start metric on partition/node 
               INNER JOIN t_vm vm ON vm.base_layer_id = vmn.base_layer_id 
                     AND vm.depth = 1
               LEFT OUTER JOIN custom.measure_v ml ON ml.target_id = avr.layer_id
                     AND ml.metric = 'LOGICAL_PROCESSORS'
                     AND ml.end_time = '9999-12-31 00:00:00.000'
               LEFT OUTER JOIN custom.measure_v m ON m.target_id = vm.id
                     AND m.metric = 'TOTAL_PROC_BY_CORES'
                     AND m.end_time = '9999-12-31 00:00:00.000'
               LEFT OUTER JOIN custom.measure_v mv ON mv.target_id = avr.layer_id
                     AND mv.metric = 'TOTAL_PROC_BY_CORES'
                     AND mv.end_time = '9999-12-31 00:00:00.000'
               LEFT OUTER JOIN custom.measure_v mo ON mo.target_id = vm.id
                     AND mo.metric = 'PROCESSOR_TYPE'
                     AND mo.end_time = '9999-12-31 00:00:00.000'
               LEFT OUTER JOIN custom.measure_v msm ON msm.target_id = vm.id
                     AND msm.metric = 'SYSTEM_MODEL'
                     AND msm.end_time = '9999-12-31 00:00:00.000'
               LEFT OUTER JOIN custom.measure_v muc ON muc.target_id = vm.id
                     AND muc.metric = 'UNLIMITED_CORES'
                     AND muc.end_time = '9999-12-31 00:00:00.000'
                --- end metric on partition/node
               JOIN table (adm.split_qualifier (mo.qualifier, CHR(7))) qual ON 1 = 1
               LEFT OUTER JOIN custom.processor_value_unit_v pt ON scr.processor_id = pt.id
                     AND pt.end_date = '9999-12-31 00:00:00.000') AS processors%
		

comment on table CUSTOM.PROCESSOR_INFO_V is 'Summary of processors/cores information'%
comment on column CUSTOM.PROCESSOR_INFO_V.hostname is 'host name of guest operating system (virtual partition)'%
comment on column CUSTOM.PROCESSOR_INFO_V.node_name is 'name of hardware node (physical server)'%
comment on column CUSTOM.PROCESSOR_INFO_V.node_id is 'id of node'%
comment on column CUSTOM.PROCESSOR_INFO_V.system_model is 'hardware model name of hardware node'%
comment on column CUSTOM.PROCESSOR_INFO_V.platform is 'hardware platform of the node'%
comment on column CUSTOM.PROCESSOR_INFO_V.processor_coreness is 'number of cores of the node matched in PVU table'%
comment on column CUSTOM.PROCESSOR_INFO_V.processor_brand is 'processor brand name matched in PVU table'%
comment on column CUSTOM.PROCESSOR_INFO_V.raw_processor_brand is 'processor brand in format, that is sent by the agent (may be NULL)'%
comment on column CUSTOM.PROCESSOR_INFO_V.processor_vendor is 'processor vendor name matched in PVU table'%
comment on column CUSTOM.PROCESSOR_INFO_V.raw_processor_vendor is 'processor vendor in format, that is sent by the agent (may be NULL)'%
comment on column CUSTOM.PROCESSOR_INFO_V.processor_model is 'processor model matched in PVU table'%
comment on column CUSTOM.PROCESSOR_INFO_V.raw_processor_model is 'processor model in format, that is sent by te agent (may be NULL)'%
comment on column CUSTOM.PROCESSOR_INFO_V.no_active_sockets is 'number of active processor sockets on the node'%
comment on column CUSTOM.PROCESSOR_INFO_V.no_active_cores_srv is 'number of active processor cores on the node'%
comment on column CUSTOM.PROCESSOR_INFO_V.no_active_cores_srv_bios is 'number of active processor cores enabled in BIOS/OS (works only on x86 OS installed directly on node)'%
comment on column CUSTOM.PROCESSOR_INFO_V.no_logical_processors is 'number of logical processors on the virtual partition (reported by OS)'%
comment on column CUSTOM.PROCESSOR_INFO_V.no_partition_cores is 'number of processor cores assigned to the virtual partition'%
comment on column CUSTOM.PROCESSOR_INFO_V.cpu_frequency is 'CPU frequency'% 

-- clean up
--#pragma ignore -551 
call ADM.RESTORE_VIEW_ACCESS%
call ADM.DROP_IF_EXISTS('table ADM.FP_SAVE_GRANTS')%

drop procedure ADM.DROP_IF_EXISTS%
drop procedure ADM.RESTORE_VIEW_ACCESS%

-- Just to be sure that tlmsrv have proper rights level
GRANT SELECT ON CUSTOM.PROCESSOR_INFO_V to user tlmsrv%

disconnect current%
