CONNECT TO TLMA%

CREATE PROCEDURE ADM.ADD_COLUMN_IF_NOT_EXISTS(
      in SCHEMA_NAME char(40), 
      in TABLE_NAME char(40), 
      in COLUMN_NAME char(40),
      in COLUMN_DEFINITION varchar(120))
	BEGIN
		DECLARE numRecords INT DEFAULT 0;
		DECLARE stmt VARCHAR(1000);

		SELECT COUNT(*) INTO numRecords
		FROM SYSCAT.COLUMNS 
		WHERE TABSCHEMA = SCHEMA_NAME AND TABNAME = TABLE_NAME AND COLNAME = COLUMN_NAME;
			
		SET stmt = 'ALTER TABLE ' CONCAT SCHEMA_NAME CONCAT '.' CONCAT TABLE_NAME CONCAT ' ADD COLUMN ' CONCAT COLUMN_DEFINITION;
		IF numRecords = 0 THEN
			PREPARE prep_stmt FROM stmt;
			EXECUTE prep_stmt;
		END IF;
	END%

-- create procedure that commits transaction
create procedure ADM.TRANSACTION_COMMIT_TMP(in SQL_QUERY varchar(1000))
	begin
	declare STMT varchar(1000);
	DECLARE numrows INT DEFAULT 0;

	prepare S1 from SQL_QUERY;
	
	loop_statement:
	REPEAT
		execute S1;
		GET DIAGNOSTICS numrows = ROW_COUNT;
		COMMIT;
		UNTIL numrows = 0 
	END REPEAT loop_statement;
	end%

-- if feature is ported to 7.2.2 the column could exist
CALL ADM.ADD_COLUMN_IF_NOT_EXISTS(
	'SWCAT',
	'COMPONENT',
	'IS_FREE_ONLY',
	'IS_FREE_ONLY SMALLINT NOT NULL DEFAULT 0'
)%

comment on column SWCAT.COMPONENT.IS_FREE_ONLY is 
    'Indicate whether the component has all branches free.'%

call ADM.TRANSACTION_COMMIT_TMP('
	MERGE INTO swcat.component component
	USING (
		SELECT b.component_id
		FROM swcat.branch b
		JOIN swcat.component c ON c.id = b.component_id
		WHERE b.type <> 20 AND b.deleted = 0 AND c.is_free_only = 0 
		GROUP BY b.component_id
		HAVING MAX(type) = 10
		FETCH FIRST 10000 ROWS ONLY 
	) AS comp_to_update(id)
	ON component.id = comp_to_update.id
	WHEN MATCHED THEN 
		UPDATE SET component.is_free_only = 1
')%

DROP PROCEDURE ADM.ADD_COLUMN_IF_NOT_EXISTS%

DROP PROCEDURE ADM.TRANSACTION_COMMIT_TMP%

INSERT INTO lic.control_values(
	control_key, 
	control_value, 
	control_value_type, 
	control_value_enum,
	control_hidden,
	control_units)
SELECT 'excludeFreeComponentsOnMSI', 'false', 2, 'false, true', 1, 'true/false'
FROM sysibm.sysdummy1 
WHERE NOT EXISTS (SELECT 1 FROM lic.control_values WHERE control_key = 'excludeFreeComponentsOnMSI')%

DISCONNECT CURRENT%